############################################
# IMPORT
############################################

library(foreign)
# Run if necessary the install.packages("texreg")
#install.packages("texreg") 

library("texreg")
e<-read.xport("D:\\Olivier\\Documents\\Universite\\data\\Emploi\\Jole_2009_Data\\LFS_9603_raw.xpt")
library("stargazer")

#############################################
#############################################
#Robust clustered standard errors function
clx <-
  function(fm, dfcw, cluster){
    library(sandwich)
    library(lmtest)
    M <- length(unique(cluster))
    N <- length(cluster)
    dfc <- (M/(M-1))*((N-1)/(N-fm$rank))
    u <- apply(estfun(fm),2,
               function(x) tapply(x, cluster, sum))
    vcovCL <- dfc*sandwich(fm, meat=crossprod(u)/N)*dfcw
    coeftest(fm, vcovCL) }



############################################
############################################
# VARIABLE CREATIONS
############################################
############################################


#Conversion of factor to numeric variable
e$DEA_n<-as.numeric(as.character(e$DEA))
e$HH_n<-as.numeric(as.character(e$HH))
e$EFEN98_n<-as.numeric(as.character(e$EFEN98))
e$CSE_n<-as.numeric(as.character(e$CSE))
e$AG_n<-as.numeric(as.character(e$AG))
e$AGE_n<-as.numeric(as.character(e$AGE))
e$NP_n<-as.numeric(as.character(e$NP))
e$HT_n<-as.numeric(as.character(e$HT))
e$year<-e$YEAR


#Usual working hours
e$us_hours<-ifelse(e$year<2003,e$HH_n,e$HHC)


#Last week working hours
e$lw_hours<-ifelse(e$year==2003, e$EMPNBH,e$HT_n)

#Hourly wage
e$SALRED<-ifelse(e$year==2003,e$SALRED*6.55957,e$SALRED)
e$hwage<-ifelse(e$us_hours>0,e$SALRED/(4.34*pmin(e$us_hours,48)),NA)
e$lhwage<-ifelse(e$hwage>0,log(e$hwage),NA)


#Full time 
e$fulltim<-(e$DUHAB  %in%  c("4","5","6","7"))*1


#Gender
e$female<-(e$SEXE  %in%  ("2") | e$S %in% ("2"))*1
e$male<-1-e$female

#Civil servant
e$public<-ifelse(e$year==2003,(e$CHPUB %in% c("1","2","3"))*1, (e$CHPUB %in% ("2"))*1)

#Wage earner
e$wageearn<-ifelse(e$year==2003,(e$STAT2 %in% c("2"))*1, (e$ST %in% ("2"))*1)

#Definition of living department (Department fixed effect)
e$livdep<-factor(ifelse(e$DEP %in% c("2A","2B"),"20",as.character(e$DEP)))


#Definition of working department (Department fixed effect)
e$workdep<-ifelse(e$year<2003 ,as.character(e$DEPETA),as.character(e$DEPARC))
e$workdep<-ifelse(e$workdep=="" ,as.character(e$livdep),e$workdep)
e$workdep<-factor(ifelse(e$workdep %in% c("2A","2B"),"20",e$workdep))

#Alsace Moselle 
e$alsacemo_o=(e$workdep %in% c("57","67","68"))*1 
e$alsacemo=(e$livdep %in% c("57","67","68"))*1 


#Border workers
e$borderwo=(1-(e$PETA=="10" | e$PETA==""))


####establish the correspondance with the border country:
# Here I follow exactly the program for the JOLE 2009 article; 
# Other decision could be done for some departments like Moselle (matching with Luxembourg); 
# or Haut Rhing (matching with Switzerland) and similarly Aisne (02) could be included in the ; 
# list and matched with Belgium; 
# Note that the STATA code finally attributes 74 to Italy 
e$country<-ifelse(e$livdep %in% c("08","55","59"),"Belgium",
            ifelse(e$livdep %in% "54","Luxembourg",         
             ifelse(e$livdep %in% c("57","67","68"),"Germany",
              ifelse(e$livdep %in% c("01","25","39","90"),"Switzerland",
               ifelse(e$livdep %in% c("04","05","06","73","74"),"Italy",
                ifelse(e$livdep %in% c("09","31","65","64","66"),"Spain","No border"))))))



#Bordering GDP growth; 
# Data extracted on 24 Sep 2016 10:06 UTC (GMT) from OECD.Stat;
# http://stats.oecd.org/index.aspx?DatasetCode=EO; 
oecd<-read.csv("D:\\Olivier\\Dropbox\\Repl_JOLE_2009\\Replication_JOLE_2009_Data\\growth.txt",sep="\t")
str(oecd)
e<-merge(e,oecd,by=c("year","country"),all.x=TRUE)



#Bordering departments
#Adding AISNE (very short border with Belgium)
e$country1<-ifelse(e$livdep=="2",1,1-(e$country=="No border"))


#Redefinition of living region => Moselle in Alsace
e$livreg<-ifelse(e$year<2003,as.character(e$RG),as.character(e$REG))
e$livreg<-ifelse(e$livreg %in% c("93","94"),"92",e$livreg)
e$livreg<-ifelse(e$livdep %in% "57","42",e$livreg)
e$livreg<-factor(e$livreg)


#Size of firm
e$efenn<-ifelse(e$year==2003,e$EFEN, e$EFEN98_n)
e$efenn<-ifelse(e$efenn==999999,NA,e$efenn)
e$efen99<-(is.na(e$efenn))*1
e$efen20w<-(e$efenn>19)*1
e$efen20<-(e$efen20w %in% ("1"))*1

e$tn20<-(e$TN %in% c("5","6","7","8","9"))*1
e$tn0<-(e$TN %in% c("0"))*1
e$tn99<-(e$TN %in% (""))*1
e$tn99b<-(e$TN %in% c("","0"))*1
e$tn20w<-ifelse(e$tn99==0,e$tn20,NA)
e$tn20wb<-ifelse(e$tn99b==0,e$tn20,NA)
e$tn20e<-e$tn20+e$tn99b
e$tn20e2<-e$tn20+e$tn99

e$nbsalb20<-(e$NBSALB %in% c("5","6","7","8","9"))*1
e$nbsalb0<-(e$NBSALB %in% c("1"))*1
e$nbsalb99<-(e$NBSALB %in% c("","99"))*1
e$nbsalb99b<-(e$NBSALB %in% c("","99","1"))*1
e$nbsalb20w<-ifelse(e$nbsalb99==0,e$nbsalb20,NA)*1
e$nbsalb20wb<-ifelse(e$nbsalb99b==0,e$nbsalb20,NA)*1

#Targeted occupation
e$t_occ<-(e$CSE_n %in% c(32:69) &  e$CSE !="34" & e$CSE !="42" & e$CSE !="44" & e$CSE !="56" )*1

#Targeted firm 
e$t_firm<-ifelse(e$public==1,1, 
           ifelse(e$year==2003 & e$efenn>19 & is.na(e$efenn)==FALSE,1,
            ifelse(e$year==2003 & e$efenn<20 & is.na(e$efenn)==FALSE,0,
             ifelse(e$year==2003 & e$NBSALB %in% c("5","6","7","8","9"),1,
              ifelse(e$year==2003 & e$NBSALB %in% c("0","1","2","3","4"),0,
               ifelse(e$year<2003 & e$TN %in% c("5","6","7","8","9"),1,
                ifelse(e$year>1997 & e$year<2003 & e$TN %in% c("0","1","2","3","4"),0,
                 ifelse(e$year<1998 & e$TN %in% c("1","2","3","4"),0,
                  ifelse(e$wageearn==0,0,NA)))))))))

#Targeted sector
e$sector<-factor(ifelse(e$year<2003,as.character(e$NAFG36),as.character(e$NAFG36U)))
e$t_sector<-(e$sector %in% c("F5","J3","P1","H0") )*1

#Targeted individuals
e$t_ind<-((e$t_occ+e$t_firm+e$t_sector)>=3)*1


#Age 
e$agen<-ifelse(e$year==2003,e$AGE_n,e$AG_n)
e$age1524<-(e$agen %in% c(15:24))*1
e$age2539<-(e$agen %in% c(25:39))*1
e$age4049<-(e$agen %in% c(40:49))*1
e$age5059<-(e$agen %in% c(50:59))*1
e$age60pl<-(e$agen %in% c(60:108))*1

#Household size 
e$hhldsize=pmin(ifelse(e$year<2003,e$NP_n,e$NBINDE),5)

#Diploma 
e$ddipl1<-(e$DDIPL %in% "1")
e$ddipl3<-(e$DDIPL %in% "3")
e$ddipl4<-(e$DDIPL %in% "4")
e$ddipl5<-(e$DDIPL %in% "5")
e$ddipl6<-(e$DDIPL %in% "6")
e$ddipl7<-(e$DDIPL %in% "7")
e$ddipl9<-(e$DDIPL %in% "")

#Period
e$per9900=(e$year %in% c(1999,2000))
e$per0102=(e$year %in% c(2001,2002))
e$per03=(e$year %in% c(2003))
e$period<-ifelse(e$year<1999,199698,ifelse(e$year<2001,199900,ifelse(e$year<2003,200102,200303)))

#Employment
e$act3<-ifelse(e$year<2003,as.character(e$ACT),as.character(e$ACTEU))
e$act7_n<-as.numeric(ifelse(e$year<2003,as.character(e$ACT7),as.character(e$ACTEU6)))

e$employed=(e$act3 %in% "1")*1
e$unemploy=ifelse(e$act3 %in% c("1","2"), (e$act3=="2"),NA)*1

#Alsacemo*Periods
e$alsacemo9900<-e$alsacemo*e$per9900
e$alsacemo0102<-e$alsacemo*e$per0102
e$alsacemo03<-e$alsacemo*e$per03

e$all<-1

#Fields
#Field all active
e$f1<-(e$act7_n==1|e$act7_n==3|e$act7_n==4)*1

#Field all workers full time
e$f2<-(e$f1 %in% 1 & e$fulltim %in% 1)*1

#Field all workers full time and department valid
e$f3<-(e$f2 %in% 1 & is.na(e$us_hours)==0 
       & is.na(e$livdep)==FALSE
       & is.na(e$AG5)==FALSE
       & is.na(e$hhldsize)==FALSE
       & is.na(e$CSE_n)==FALSE
       & e$EXTRI!=0 
       & is.na(e$EXTRI)==FALSE)*1

#field all workers full time and department, household and valid & not working abroad
e$f3b=(e$f3==1 & e$borderwo==0)

#Field all individuals active & inactive and department valid
e$f4<-(e$CSE_n %in% c(10:69) 
       & is.na(e$livdep)==FALSE
       & is.na(e$AG5)==FALSE
       & is.na(e$hhldsize)==FALSE
       & e$EXTRI!=0 
       & is.na(e$EXTRI)==FALSE          
       & e$year<2003)*1

#Field all individuals active and department valid
e$f5<-(e$f4==1 & (e$act7_n==1|e$act7_n==3|e$act7_n==4))*1




#############################################
#############################################
#Table G1
#############################################
#############################################
G1B1<-data.frame(tapply(e$efenn[e$f3==1],e$year[e$f3==1],mean,na.rm=TRUE),
        tapply(e$efenn[e$f3==1],e$year[e$f3==1],sd,na.rm=TRUE),
        tapply(e$efen99[e$f3==1],e$year[e$f3==1],mean,na.rm=TRUE),
        tapply(e$efen20[e$f3==1],e$year[e$f3==1],mean,na.rm=TRUE),
        tapply(e$efen20w[e$f3==1],e$year[e$f3==1],mean,na.rm=TRUE),
        tapply(e$efen20[e$f3==1]>=0,e$year[e$f3==1],sum,na.rm=TRUE))

colnames(G1B1)<-c("Mean","SD","Missing","Twentyplus","TwentyplusW","Obs")
G1B1

G1B2<-data.frame(tapply(e$tn99[e$f3==1],e$year[e$f3==1],mean,na.rm=TRUE),
               tapply(e$tn0[e$f3==1],e$year[e$f3==1],mean,na.rm=TRUE),
               tapply(e$tn99b[e$f3==1],e$year[e$f3==1],mean,na.rm=TRUE),
               tapply(e$tn20[e$f3==1],e$year[e$f3==1],mean,na.rm=TRUE),
               tapply(e$tn20wb[e$f3==1],e$year[e$f3==1],mean,na.rm=TRUE),
               tapply(e$tn20[e$f3==1]>=0,e$year[e$f3==1],sum,na.rm=TRUE))

colnames(G1B2)<-c("tn99","tn0","tn99b","tn20","tn20wb","Obs")
G1B2

G1B3<-data.frame(tapply(e$nbsalb99[e$f3==1],e$year[e$f3==1],mean,na.rm=TRUE),
                 tapply(e$nbsalb0[e$f3==1],e$year[e$f3==1],mean,na.rm=TRUE),
                 tapply(e$nbsalb99b[e$f3==1],e$year[e$f3==1],mean,na.rm=TRUE),
                 tapply(e$nbsalb20[e$f3==1],e$year[e$f3==1],mean,na.rm=TRUE),
                 tapply(e$nbsalb20wb[e$f3==1],e$year[e$f3==1],mean,na.rm=TRUE),
                 tapply(e$nbsalb20[e$f3==1]>=0,e$year[e$f3==1],sum,na.rm=TRUE))

colnames(G1B3)<-c("nbsalb99","nbsalb0","nbsalb99b","nbsalb20","nbsalb20wb","Obs")
G1B3

#############################################
#############################################
#Table G2 PANEL B Exploring Firm size
#############################################
#############################################
G2B1<-lm(us_hours~factor(year)+livdep+CSE
         +ddipl1+ddipl3+ddipl4+ddipl5+ddipl6+ddipl9
         +male+hhldsize
         +age1524+age2539+age5059+age60pl         
         +alsacemo03+alsacemo0102+alsacemo9900
         ,weight=EXTRI,data=e[e$f3==1 & e$year<2003 & e$tn20w==1,])
G2B1_r<-clx(G2B1,1,cluster=G2B1$model$livdep)
G2B1_r

G2B2<-lm(us_hours~factor(year)+livdep+CSE
         +ddipl1+ddipl3+ddipl4+ddipl5+ddipl6+ddipl9
         +male+hhldsize
         +age1524+age2539+age5059+age60pl         
         +alsacemo03+alsacemo0102+alsacemo9900
         ,weight=EXTRI,data=e[e$f3==1 & e$year<2003 & e$tn20wb==0 ,])
G2B2_r<-clx(G2B2,1,cluster=G2B2$model$livdep)
G2B2_r

G2B3<-lm(us_hours~factor(year)+livdep+CSE
         +ddipl1+ddipl3+ddipl4+ddipl5+ddipl6+ddipl9
         +male+hhldsize
         +age1524+age2539+age5059+age60pl         
         +alsacemo03+alsacemo0102+alsacemo9900
         ,weight=EXTRI,data=e[e$f3==1  & e$year<2003 & e$tn99b==1,])
G2B3_r<-clx(G2B3,1,cluster=G2B3$model$livdep)
G2B3_r


G2B4<-lm(us_hours~tn20wb*factor(year)+tn20wb*livdep+tn20wb*CSE
         +ddipl1+ddipl3+ddipl4+ddipl5+ddipl6+ddipl9
         +male+hhldsize
         +age1524+age2539+age5059+age60pl         
         +tn20wb*alsacemo03+tn20wb*alsacemo0102+tn20wb*alsacemo9900
         ,weight=EXTRI,data=e[e$f3==1 & e$year<2003,])
G2B4_r<-clx(G2B4,1,cluster=G2B4$model$livdep)
G2B4_r

G2B5<-lm(us_hours~tn20*factor(year)+tn20*livdep+tn20*CSE
         +ddipl1+ddipl3+ddipl4+ddipl5+ddipl6+ddipl9
         +male+hhldsize
         +age1524+age2539+age5059+age60pl
         +tn20*alsacemo03+tn20*alsacemo0102+tn20*alsacemo9900
         ,weight=EXTRI,data=e[e$f3==1 & e$year<2003,])
G2B5_r<-clx(G2B5,1,cluster=G2B5$model$livdep)
G2B5_r

G2B6<-lm(us_hours~factor(year)+livdep+CSE
         +ddipl1+ddipl3+ddipl4+ddipl5+ddipl6+ddipl9
         +male+hhldsize
         +age1524+age2539+age5059+age60pl         
         +alsacemo03+alsacemo0102+alsacemo9900
         ,weight=EXTRI,data=e[e$f3==1 & e$year<2003 & e$tn20e==1 ,])
G2B6_r<-clx(G2B6,1,cluster=G2B6$model$livdep)
G2B6_r

G2B7<-lm(us_hours~tn20e*factor(year)+tn20e*livdep+tn20e*CSE
         +ddipl1+ddipl3+ddipl4+ddipl5+ddipl6+ddipl9
         +male+hhldsize
         +age1524+age2539+age5059+age60pl         
         +tn20e*alsacemo03+tn20e*alsacemo0102+tn20e*alsacemo9900
         ,weight=EXTRI,data=e[e$f3==1 & e$year<2003,])
G2B7_r<-clx(G2B7,1,cluster=G2B7$model$livdep)
G2B7_r


screenreg(list(G2B1_r,G2B2_r,G2B3_r,G2B4_r,G2B5_r,G2B6_r,G2B7_r),
          custom.model.names = c("DD_tn20w1","DD_tn20w0","DD_tn0","DDD_tn20wb","DDD_tn20","DD_tn20e","DDD_tn20e"),
          omit.coef = "(livdep)|(age)|(CSE)|(ddipl)|(year)|(male)|(hhld)|(Intercept)",
          stars = c(0.01, 0.05, 0.1),digits = 4)
htmlreg(list(G2B1_r,G2B2_r,G2B3_r,G2B4_r,G2B5_r,G2B6_r,G2B7_r),
        custom.model.names = c("DD_tn20w1","DD_tn20w0","DD_tn0","DDD_tn20wb","DDD_tn20","DD_tn20e","DDD_tn20e"),
        omit.coef = "(livdep)|(age)|(CSE)|(ddipl)|(year)|(male)|(hhld)|(Intercept)",
        stars = c(0.01, 0.05, 0.1),digits = 4,file="tableG2B.html")
screenreg(list(G2B1,G2B2,G2B3,G2B4,G2B5,G2B6,G2B7),
          custom.model.names = c("DD_tn20w1","DD_tn20w0","DD_tn0","DDD_tn20wb","DDD_tn20w","DD_tn20e","DDD_tn20e"),
          omit.coef = "(livdep)|(age)|(CSE)|(ddipl)|(year)|(male)|(hhld)|(Intercept)",
          stars = c(0.01, 0.05, 0.1),digits = 4)
htmlreg(list(G2B1_r,G2B2_r,G2B3_r,G2B4_r,G2B5_r,G2B6_r,G2B7_r),
        custom.model.names = c("DD_tn20w1","DD_tn20w0","DD_tn0","DDD_tn20wb","DDD_tn20","DD_tn20e","DDD_tn20e"),
        omit.coef = "(livdep)|(age)|(CSE)|(ddipl)|(year)|(male)|(hhld)|(Intercept)",
        stars = c(0.01, 0.05, 0.1),digits = 4,file="tableG2B_ols.html")


screenreg(list(G2B1_r,G2B2_r,G2B3_r,G2B4_r,G2B5_r,G2B6_r,G2B7_r),
          custom.model.names = c("DD_tn20w1","DD_tn20w0","DD_tn0","DDD_tn20wb","DDD_tn20","DD_tn20e","DDD_tn20e"),
          stars = c(0.01, 0.05, 0.1),digits = 4)
htmlreg(list(G2B1_r,G2B2_r,G2B3_r,G2B4_r,G2B5_r,G2B6_r,G2B7_r),
        custom.model.names = c("DD_tn20w1","DD_tn20w0","DD_tn0","DDD_tn20wb","DDD_tn20","DD_tn20e","DDD_tn20e"),
        stars = c(0.01, 0.05, 0.1),digits = 4,file="tableG2B_full.html")


#Removing results for liberating RAM
rm(G2B1,G2B2,G2B3,G2B4,G2B5,G2B6,G2B7)


#############################################
#############################################
#Table G3A. PANEL A REPLICATING TABLE A
#############################################
#############################################
G3A1<-lm(us_hours~factor(year)+livdep+CSE
         +ddipl1+ddipl3+ddipl4+ddipl5+ddipl6+ddipl9
         +male+hhldsize
         +age1524+age2539+age5059+age60pl         
         +alsacemo03+alsacemo0102+alsacemo9900
                 ,weight=EXTRI,data=e[e$f3==1 & e$t_occ==1,])
G3A1_r<-clx(G3A1,1,cluster=G3A1$model$livdep)
G3A1_r


G3A2<-lm(us_hours~factor(year)+livdep+CSE
         +ddipl1+ddipl3+ddipl4+ddipl5+ddipl6+ddipl9
         +male+hhldsize
         +age1524+age2539+age5059+age60pl              
         +alsacemo03+alsacemo0102+alsacemo9900
                 ,weight=EXTRI,data=e[e$f3==1 & e$t_occ==0 ,])
G3A2_r<-clx(G3A2,1,cluster=G3A2$model$livdep)
G3A2_r



G3A3<-lm(us_hours~t_occ*factor(year)+t_occ*livdep+t_occ*CSE
         +ddipl1+ddipl3+ddipl4+ddipl5+ddipl6+ddipl9
         +male+hhldsize
         +age1524+age2539+age5059+age60pl         
         +t_occ*alsacemo03+t_occ*alsacemo0102+t_occ*alsacemo9900
                 ,weight=EXTRI,data=e[e$f3==1 ,])
G3A3_r<-clx(G3A3,1,cluster=G3A3$model$livdep)
G3A3_r


G3A4<-lm(us_hours~factor(year)+livdep+CSE
         +ddipl1+ddipl3+ddipl4+ddipl5+ddipl6+ddipl9
         +male+hhldsize
         +age1524+age2539+age5059+age60pl         
         +alsacemo03+alsacemo0102+alsacemo9900
                 ,weight=EXTRI,data=e[e$f3==1 & e$t_ind==1 ,])
G3A4_r<-clx(G3A4,1,cluster=G3A4$model$livdep)
G3A4_r



G3A5<-lm(us_hours~factor(year)+livdep+CSE
         +ddipl1+ddipl3+ddipl4+ddipl5+ddipl6+ddipl9
         +male+hhldsize
         +age1524+age2539+age5059+age60pl         
         +alsacemo03+alsacemo0102+alsacemo9900
                 ,weight=EXTRI,data=e[e$f3==1 & e$t_ind==0 ,])
G3A5_r<-clx(G3A5,1,cluster=G3A5$model$livdep)
G3A5_r
rm(G3A5_r$model)

G3A6<-lm(us_hours~t_ind*factor(year)+t_ind*livdep+t_ind*CSE     
         +ddipl1+ddipl3+ddipl4+ddipl5+ddipl6+ddipl9
         +male+hhldsize
         +age1524+age2539+age5059+age60pl         
         +t_ind*alsacemo03+t_ind*alsacemo0102+t_ind*alsacemo9900
                 ,weight=EXTRI,data=e[e$f3==1 ,])
G3A6_r<-clx(G3A6,1,cluster=G3A6$model$livdep)
G3A6_r


G3A7<-lm(us_hours~factor(year)+livdep+CSE
         +ddipl1+ddipl3+ddipl4+ddipl5+ddipl6+ddipl9
         +male+hhldsize
         +age1524+age2539+age5059+age60pl         
         +alsacemo03+alsacemo0102+alsacemo9900+bordergdp
         ,weight=EXTRI,data=e[e$f3==1 & e$t_ind==1 ,])
G3A7_r<-clx(G3A7,1,cluster=G3A7$model$livdep)
G3A7_r

screenreg(list(G3A1_r,G3A2_r,G3A3_r,G3A4_r,G3A5_r,G3A6_r,G3A7_r),
          custom.model.names = c("DD_occ1","DD_occ0","DDD_occ","DD_ind1","DD_ind0","DDD_ind","DD_ind+border"),
          omit.coef = "(livdep)|(age)|(CSE)|(ddipl)|(year)|(male)|(hhld)|(Intercept)",
          stars = c(0.01, 0.05, 0.1),digits = 4)
htmlreg(list(G3A1_r,G3A2_r,G3A3_r,G3A4_r,G3A5_r,G3A6_r,G3A7_r),
        custom.model.names = c("DD_occ1","DD_occ0","DDD_occ","DD_ind1","DD_ind0","DDD_ind","DD_ind+border"),
        omit.coef = "(livdep)|(age)|(CSE)|(ddipl)|(year)|(male)|(hhld)",
        stars = c(0.01, 0.05, 0.1),digits = 4,file="tableG3A.html")
screenreg(list(G3A1,G3A2,G3A3,G3A4,G3A5,G3A6,G3A7),
          custom.model.names = c("DD_occ1","DD_occ0","DDD_occ","DD_ind1","DD_ind0","DDD_ind","DD_ind+border"),
          omit.coef = "(livdep)|(age)|(CSE)|(ddipl)|(year)|(male)|(hhld)",
          stars = c(0.01, 0.05, 0.1),digits = 4)
htmlreg(list(G3A1,G3A2,G3A3,G3A4,G3A5,G3A6,G3A7),
        custom.model.names = c("DD_occ1","DD_occ0","DDD_occ","DD_ind1","DD_ind0","DDD_ind","DD_ind+border"),
        omit.coef = "(livdep)|(age)|(CSE)|(ddipl)|(year)|(male)|(hhld)",
        stars = c(0.01, 0.05, 0.1),digits = 4,file="tableG3A_ols.html")
screenreg(list(G3A1_r,G3A2_r,G3A3_r,G3A4_r,G3A5_r,G3A6_r,G3A7_r),
          custom.model.names = c("DD_occ1","DD_occ0","DDD_occ","DD_ind1","DD_ind0","DDD_ind","DD_ind+border"),
          stars = c(0.01, 0.05, 0.1),digits = 4)
htmlreg(list(G3A1_r,G3A2_r,G3A3_r,G3A4_r,G3A5_r,G3A6_r,G3A7_r),
        custom.model.names = c("DD_occ1","DD_occ0","DDD_occ","DD_ind1","DD_ind0","DDD_ind","DD_ind+border"),
        stars = c(0.01, 0.05, 0.1),digits = 4,file="tableG3A_full.html")
#Removing results for liberating RAM
rm(G3A1,G3A2,G3A3,G3A4,G3A5,G3A6,G3A7)


#############################################
#############################################
#Table G3 PANEL B REPLICATING TABLE A2
#############################################
#############################################

G3B1<-lm(us_hours~factor(year)+livdep+CSE+ddipl1+ddipl3+ddipl4+ddipl5+ddipl6+ddipl9+male
                   +hhldsize+age1524+age2539+age5059+age60pl+alsacemo03+alsacemo0102+alsacemo9900
                   ,weight=EXTRI,data=e[e$f3==1 & e$t_firm==1 ,])
G3B1_r<-clx(G3B1,1,cluster=G3B1$model$livdep)
G3B1_r

G3B2<-lm(us_hours~factor(year)+livdep+CSE+ddipl1+ddipl3+ddipl4+ddipl5+ddipl6+ddipl9+male
                   +hhldsize+age1524+age2539+age5059+age60pl+alsacemo03+alsacemo0102+alsacemo9900
                   ,weight=EXTRI,data=e[e$f3==1 & e$t_firm==0 ,])
G3B2_r<-clx(G3B2,1,cluster=G3B2$model$livdep)
G3B2_r

G3B3<-lm(us_hours~t_firm*factor(year)+t_firm*livdep+t_firm*CSE
        +ddipl1+ddipl3+ddipl4+ddipl5+ddipl6+ddipl9+male
         +hhldsize+age1524+age2539+age5059+age60pl+
                   +t_firm*alsacemo03+t_firm*alsacemo0102+t_firm*alsacemo9900
                   ,weight=EXTRI,data=e[e$f3==1 ,])
G3B3_r<-clx(G3B3,1,cluster=G3B3$model$livdep)
G3B3_r

G3B4<-lm(us_hours~factor(year)+livdep+CSE+ddipl1+ddipl3+ddipl4+ddipl5+ddipl6+ddipl9+male
                     +hhldsize+age1524+age2539+age5059+age60pl+alsacemo03+alsacemo0102+alsacemo9900
                     ,weight=EXTRI,data=e[e$f3==1 & e$t_sector==1 ,])
G3B4_r<-clx(G3B4,1,cluster=G3B4$model$livdep)
G3B4_r

G3B5<-lm(us_hours~factor(year)+livdep+CSE+ddipl1+ddipl3+ddipl4+ddipl5+ddipl6+ddipl9+male
                     +hhldsize+age1524+age2539+age5059+age60pl+alsacemo03+alsacemo0102+alsacemo9900
                     ,weight=EXTRI,data=e[e$f3==1 & e$t_sector==0 ,])
G3B5_r<-clx(G3B5,1,cluster=G3B5$model$livdep)
G3B5_r

G3B6<-lm(us_hours~t_sector*factor(year)+t_sector*livdep+t_sector*CSE
         +ddipl1+ddipl3+ddipl4+ddipl5+ddipl6+ddipl9+male
         +hhldsize+age1524+age2539+age5059+age60pl
         +t_sector*alsacemo03+t_sector*alsacemo0102+t_sector*alsacemo9900
                     ,weight=EXTRI,data=e[e$f3==1 ,])
G3B6_r<-clx(G3B6,1,cluster=G3B6$model$livdep)
G3B6_r


screenreg(list(G3B1_r,G3B2_r,G3B3_r,G3B4_r,G3B5_r,G3B6_r),
          custom.model.names = c("DD_firm1","DD_firm0","DDD_firm","DD_sector1","DD_sector0","DDD_sector"),
          omit.coef = "(livdep)|(age)|(CSE)|(ddipl)|(year)|(male)|(hhld)",
          stars = c(0.01, 0.05, 0.1),digits = 4)
htmlreg(list(G3B1_r,G3B2_r,G3B3_r,G3B4_r,G3B5_r,G3B6_r),
        custom.model.names = c("DD_firm1","DD_firm0","DDD_firm","DD_sector1","DD_sector0","DDD_sector"),
        omit.coef = "(livdep)|(age)|(CSE)|(ddipl)|(year)|(male)|(hhld)",
        stars = c(0.01, 0.05, 0.1),digits = 4,file="tableG3B.html")
screenreg(list(G3B1,G3B2,G3B3,G3B4,G3B5,G3B6),
          custom.model.names = c("DD_firm1","DD_firm0","DDD_firm","DD_sector1","DD_sector0","DDD_sector"),
          omit.coef = "(livdep)|(age)|(CSE)|(ddipl)|(year)|(male)|(hhld)",
          stars = c(0.01, 0.05, 0.1),digits = 4)
htmlreg(list(G3B1,G3B2,G3B3,G3B4,G3B5,G3B6),
        custom.model.names = c("DD_firm1","DD_firm0","DDD_firm","DD_sector1","DD_sector0","DDD_sector"),
        omit.coef = "(livdep)|(age)|(CSE)|(ddipl)|(year)|(male)|(hhld)",
        stars = c(0.01, 0.05, 0.1),digits = 4,file="tableG3B_ols.html")
screenreg(list(G3B1_r,G3B2_r,G3B3_r,G3B4_r,G3B5_r,G3B6_r),
          custom.model.names = c("DD_firm1","DD_firm0","DDD_firm","DD_sector1","DD_sector0","DDD_sector"),
          stars = c(0.01, 0.05, 0.1),digits = 4)
htmlreg(list(G3B1_r,G3B2_r,G3B3_r,G3B4_r,G3B5_r,G3B6_r),
        custom.model.names = c("DD_firm1","DD_firm0","DDD_firm","DD_sector1","DD_sector0","DDD_sector"),
        stars = c(0.01, 0.05, 0.1),digits = 4,file="tableG3B_full.html")

#Removing results for liberating RAM
rm(G3B1,G3B2,G3B3,G3B4,G3B5,G3B6)


#############################################
#############################################
#Table G4
#############################################
#############################################
G4a<-data.frame(tapply(e$borderwo[e$f3==1 & e$country1==1],e$livdep[e$f3==1 & e$country1==1],mean,na.rm=TRUE),
                 tapply(e$borderwo[e$f3==1 & e$country1==1]>-1,e$livdep[e$f3==1 & e$country1==1],sum,na.rm=TRUE))

colnames(G4a)<-c("Percent","Obs")
G4a[is.na(G4a$Percent)==FALSE,]

G4b<-data.frame(tapply(e$borderwo[e$f3==1 & e$country1==1],e$alsacemo[e$f3==1 & e$country1==1],mean,na.rm=TRUE),
                tapply(e$borderwo[e$f3==1 & e$country1==1]>-1,e$alsacemo[e$f3==1 & e$country1==1],sum,na.rm=TRUE))
colnames(G4b)<-c("Percent","Obs")
G4b[is.na(G4b$Percent)==FALSE,]

G4c<-data.frame(tapply(e$borderwo[e$f3==1 ],e$country1[e$f3==1 ],mean,na.rm=TRUE),
                tapply(e$borderwo[e$f3==1 ]>-1,e$country1[e$f3==1],sum,na.rm=TRUE))
colnames(G4c)<-c("Percent","Obs")
G4c[is.na(G4c$Percent)==FALSE,]

#############################################
#############################################
#Figure G1
#############################################
#############################################
FG1<-data.frame(tapply(e$us_hours[e$f3==1 & e$t_occ==1 & e$alsacemo==0],e$year[e$f3==1 & e$t_occ==1 & e$alsacemo==0],mean,na.rm=TRUE),
                tapply(e$us_hours[e$f3==1 & e$t_occ==1 & e$alsacemo==0],e$year[e$f3==1 & e$t_occ==1 & e$alsacemo==0],sd,na.rm=TRUE),
                tapply(e$us_hours[e$f3==1 & e$t_occ==1 & e$alsacemo==0]>-1,e$year[e$f3==1 & e$t_occ==1 & e$alsacemo==0],sum,na.rm=TRUE),
                tapply(e$us_hours[e$f3==1 & e$t_occ==1 & e$alsacemo==1],e$year[e$f3==1 & e$t_occ==1 & e$alsacemo==1],mean,na.rm=TRUE),
                tapply(e$us_hours[e$f3==1 & e$t_occ==1 & e$alsacemo==1],e$year[e$f3==1 & e$t_occ==1 & e$alsacemo==1],sd,na.rm=TRUE),
                tapply(e$us_hours[e$f3==1 & e$t_occ==1 & e$alsacemo==1]>-1,e$year[e$f3==1 & e$t_occ==1 & e$alsacemo==1],sum,na.rm=TRUE),
                tapply(e$us_hours[e$f3==1 & e$t_occ==1 & e$alsacemo==1 & e$borderwo==1],e$year[e$f3==1 & e$t_occ==1 & e$alsacemo==1 & e$borderwo==1],mean,na.rm=TRUE),
                tapply(e$us_hours[e$f3==1 & e$t_occ==1 & e$alsacemo==1 & e$borderwo==1],e$year[e$f3==1 & e$t_occ==1 & e$alsacemo==1 & e$borderwo==1],sd,na.rm=TRUE),
                tapply(e$us_hours[e$f3==1 & e$t_occ==1 & e$alsacemo==1 & e$borderwo==1]>-1,e$year[e$f3==1 & e$t_occ==1 & e$alsacemo==1 & e$borderwo==1],sum,na.rm=TRUE),
                tapply(e$us_hours[e$f3==1 & e$t_occ==1 & e$alsacemo==1 & e$borderwo==0],e$year[e$f3==1 & e$t_occ==1 & e$alsacemo==1 & e$borderwo==0],mean,na.rm=TRUE),
                tapply(e$us_hours[e$f3==1 & e$t_occ==1 & e$alsacemo==1 & e$borderwo==0],e$year[e$f3==1 & e$t_occ==1 & e$alsacemo==1 & e$borderwo==0],sd,na.rm=TRUE),
                tapply(e$us_hours[e$f3==1 & e$t_occ==1 & e$alsacemo==1 & e$borderwo==0]>-1,e$year[e$f3==1 & e$t_occ==1 & e$alsacemo==1 & e$borderwo==0],sum,na.rm=TRUE)            
                )

colnames(FG1)<-c("FceMean","FceSD","FceN","AlsMean","AlsSD","AlsN","AlsBMean","AlsBSD","AlsBN","AlsFMean","AlsFSD","AlsFN")
FG1$FceLCL<-FG1$FceMean-1.96*FG1$FceSD/(FG1$FceN)**0.5
FG1$FceUCL<-FG1$FceMean+1.96*FG1$FceSD/(FG1$FceN)**0.5
FG1$AlsLCL<-FG1$AlsMean-1.96*FG1$AlsSD/(FG1$AlsN)**0.5
FG1$AlsUCL<-FG1$AlsMean+1.96*FG1$AlsSD/(FG1$AlsN)**0.5
FG1$AlsBLCL<-FG1$AlsBMean-1.96*FG1$AlsBSD/(FG1$AlsBN)**0.5
FG1$AlsBUCL<-FG1$AlsBMean+1.96*FG1$AlsBSD/(FG1$AlsBN)**0.5
FG1$AlsFLCL<-FG1$AlsFMean-1.96*FG1$AlsFSD/(FG1$AlsFN)**0.5
FG1$AlsFUCL<-FG1$AlsFMean+1.96*FG1$AlsFSD/(FG1$AlsFN)**0.5
FG1

matplot(rownames(FG1),FG1[,c(1,4,7,10,13,15,17,19,14,16,18,20)],type=c("b","b","b","b","l","l","l","l","l","l","l","l"),
        col = 1:4,lty=c(1,1,1,1,9,9,9,9,8,8,8,8))
legend("bottomleft", legend = colnames(FG1[,c(1,4,7,10)]),pch=1,col = 1:4) 


#############################################
#############################################
#Table G5A. PANEL A REPLICATING TABLE A
#############################################
#############################################
G5A1<-lm(us_hours~factor(year)+livdep+CSE+ddipl1+ddipl3+ddipl4+ddipl5+ddipl6+ddipl9+male
         +hhldsize+age1524+age2539+age5059+age60pl+alsacemo03+alsacemo0102+alsacemo9900
         ,weight=EXTRI,data=e[e$f3b==1 & e$t_occ==1,])
G5A1_r<-clx(G5A1,1,cluster=G5A1$model$livdep)
G5A1_r



G5A2<-lm(us_hours~factor(year)+livdep+CSE+ddipl1+ddipl3+ddipl4+ddipl5+ddipl6+ddipl9+male
         +hhldsize+age1524+age2539+age5059+age60pl+alsacemo03+alsacemo0102+alsacemo9900
         ,weight=EXTRI,data=e[e$f3b==1 & e$t_occ==0 ,])
G5A2_r<-clx(G5A2,1,cluster=G5A2$model$livdep)
G5A2_r



G5A3<-lm(us_hours~t_occ*factor(year)+t_occ*livdep+t_occ*CSE+ddipl1+ddipl3
         +ddipl4+ddipl5+ddipl6+ddipl9+male
         +hhldsize+age1524+age2539+age5059
         +age60pl+t_occ*alsacemo0102+t_occ*alsacemo9900
         +t_occ*alsacemo03
         ,weight=EXTRI,data=e[e$f3b==1 ,])
G5A3_r<-clx(G5A3,1,cluster=G5A3$model$livdep)
G5A3_r


G5A4<-lm(us_hours~factor(year)+livdep+CSE+ddipl1+ddipl3+ddipl4+ddipl5+ddipl6+ddipl9+male
         +hhldsize+age1524+age2539+age5059+age60pl+alsacemo03+alsacemo0102+alsacemo9900
         ,weight=EXTRI,data=e[e$f3b==1 & e$t_ind==1 ,])
G5A4_r<-clx(G5A4,1,cluster=G5A4$model$livdep)
G5A4_r


G5A5<-lm(us_hours~factor(year)+livdep+CSE+ddipl1+ddipl3+ddipl4+ddipl5+ddipl6+ddipl9+male
         +hhldsize+age1524+age2539+age5059+age60pl+alsacemo03+alsacemo0102+alsacemo9900
         ,weight=EXTRI,data=e[e$f3b==1 & e$t_ind==0 ,])
G5A5_r<-clx(G5A5,1,cluster=G5A5$model$livdep)
G5A5_r


G5A6<-lm(us_hours~t_ind*factor(year)+t_ind*livdep+t_ind*CSE
         +ddipl1+ddipl3+ddipl4+ddipl5+ddipl6+ddipl9+male
         +hhldsize+age1524+age2539+age5059+age60pl+
         +t_ind*alsacemo9900+t_ind*alsacemo0102+t_ind*alsacemo03
         ,weight=EXTRI,data=e[e$f3b==1 ,])
G5A6_r<-clx(G5A6,1,cluster=G5A6$model$livdep)
G5A6_r

G5A7<-lm(us_hours~factor(year)+livdep+CSE+ddipl1+ddipl3+ddipl4+ddipl5+ddipl6+ddipl9+male
         +hhldsize+age1524+age2539+age5059+age60pl+alsacemo03+alsacemo0102+alsacemo9900
         +bordergdp
         ,weight=EXTRI,data=e[e$f3b==1 & e$t_ind==1 ,])
G5A7_r<-clx(G5A7,1,cluster=G5A7$model$livdep)
G5A7_r


screenreg(list(G5A1_r,G5A2_r,G5A3_r,G5A4_r,G5A5_r,G5A6_r,G5A7_r),
          custom.model.names = c("DD_occ1","DD_occ0","DDD_occ","DD_ind1","DD_ind0","DDD_ind","DD_ind+border"),
          omit.coef = "(livdep)|(age)|(CSE)|(ddipl)|(year)|(male)|(hhld)",
          stars = c(0.01, 0.05, 0.1),digits = 4)
htmlreg(list(G5A1_r,G5A2_r,G5A3_r,G5A4_r,G5A5_r,G5A6_r,G5A7_r),
        custom.model.names = c("DD_occ1","DD_occ0","DDD_occ","DD_ind1","DD_ind0","DDD_ind","DD_ind+border"),
        omit.coef = "(livdep)|(age)|(CSE)|(ddipl)|(year)|(male)|(hhld)",
        stars = c(0.01, 0.05, 0.1),digits = 4,file="tableG5A.html")
screenreg(list(G5A1,G5A2,G5A3,G5A4,G5A5,G5A6,G5A7),
          custom.model.names = c("DD_occ1","DD_occ0","DDD_occ","DD_ind1","DD_ind0","DDD_ind","DD_ind+border"),
          omit.coef = "(livdep)|(age)|(CSE)|(ddipl)|(year)|(male)|(hhld)",
          stars = c(0.01, 0.05, 0.1),digits = 4)
htmlreg(list(G5A1,G5A2,G5A3,G5A4,G5A5,G5A6,G5A7),
        custom.model.names = c("DD_occ1","DD_occ0","DDD_occ","DD_ind1","DD_ind0","DDD_ind","DD_ind+border"),
        omit.coef = "(livdep)|(age)|(CSE)|(ddipl)|(year)|(male)|(hhld)",
        stars = c(0.01, 0.05, 0.1),digits = 4,file="tableG5A_ols.html")

screenreg(list(G5A1_r,G5A2_r,G5A3_r,G5A4_r,G5A5_r,G5A6_r,G5A7_r),
          custom.model.names = c("DD_occ1","DD_occ0","DDD_occ","DD_ind1","DD_ind0","DDD_ind","DD_ind+border"),
          stars = c(0.01, 0.05, 0.1),digits = 4)
htmlreg(list(G5A1_r,G5A2_r,G5A3_r,G5A4_r,G5A5_r,G5A6_r,G5A7_r),
        custom.model.names = c("DD_occ1","DD_occ0","DDD_occ","DD_ind1","DD_ind0","DDD_ind","DD_ind+border"),
        stars = c(0.01, 0.05, 0.1),digits = 4,file="tableG5A_full.html")


#Removing results for liberating RAM
rm(G5A1,G5A2,G5A3,G5A4,G5A5,G5A6,G5A7)



#############################################
#############################################
#Table G5 PANEL B REPLICATING TABLE A2
#############################################
#############################################

G5B1<-lm(us_hours~factor(year)+livdep+CSE+ddipl1+ddipl3+ddipl4+ddipl5+ddipl6+ddipl9+male
         +hhldsize+age1524+age2539+age5059+age60pl+alsacemo03+alsacemo0102+alsacemo9900
         ,weight=EXTRI,data=e[e$f3b==1 & e$t_firm==1 ,])
G5B1_r<-clx(G5B1,1,cluster=G5B1$model$livdep)
G5B1_r

G5B2<-lm(us_hours~factor(year)+livdep+CSE+ddipl1+ddipl3+ddipl4+ddipl5+ddipl6+ddipl9+male
         +hhldsize+age1524+age2539+age5059+age60pl+alsacemo03+alsacemo0102+alsacemo9900
         ,weight=EXTRI,data=e[e$f3b==1 & e$t_firm==0 ,])
G5B2_r<-clx(G5B2,1,cluster=G5B2$model$livdep)
G5B2_r

G5B3<-lm(us_hours~t_firm*factor(year)+t_firm*livdep+t_firm*CSE
         +ddipl1+ddipl3+ddipl4+ddipl5+ddipl6+ddipl9+male
         +hhldsize+age1524+age2539+age5059+age60pl+
         +t_firm*alsacemo03+t_firm*alsacemo0102+t_firm*alsacemo9900
         ,weight=EXTRI,data=e[e$f3b==1 ,])
G5B3_r<-clx(G5B3,1,cluster=G5B3$model$livdep)
G5B3_r

G5B4<-lm(us_hours~factor(year)+livdep+CSE+ddipl1+ddipl3+ddipl4+ddipl5+ddipl6+ddipl9+male
         +hhldsize+age1524+age2539+age5059+age60pl+alsacemo03+alsacemo0102+alsacemo9900
         ,weight=EXTRI,data=e[e$f3b==1 & e$t_sector==1 ,])
G5B4_r<-clx(G5B4,1,cluster=G5B4$model$livdep)
G5B4_r

G5B5<-lm(us_hours~factor(year)+livdep+CSE+ddipl1+ddipl3+ddipl4+ddipl5+ddipl6+ddipl9+male
         +hhldsize+age1524+age2539+age5059+age60pl+alsacemo03+alsacemo0102+alsacemo9900
         ,weight=EXTRI,data=e[e$f3b==1 & e$t_sector==0 ,])
G5B5_r<-clx(G5B5,1,cluster=G5B5$model$livdep)
G5B5_r

G5B6<-lm(us_hours~t_sector*factor(year)+t_sector*livdep+t_sector*CSE
         +ddipl1+ddipl3+ddipl4+ddipl5+ddipl6+ddipl9+male
         +hhldsize+age1524+age2539+age5059+age60pl+
         +t_sector*alsacemo03+t_sector*alsacemo0102
         +t_sector*alsacemo9900
         ,weight=EXTRI,data=e[e$f3b==1 ,])
G5B6_r<-clx(G5B6,1,cluster=G5B6$model$livdep)
G5B6_r


G5B7<-lm(us_hours~t_firm*factor(year)+t_firm*livdep+t_firm*CSE
         +ddipl1+ddipl3+ddipl4+ddipl5+ddipl6+ddipl9+male
         +hhldsize+age1524+age2539+age5059+age60pl+
           +t_firm*alsacemo03+t_firm*alsacemo0102+t_firm*alsacemo9900
         ,weight=EXTRI,data=e[e$f3b==1 & e$t_occ==1 ,])
G5B7_r<-clx(G5B7,1,cluster=G5B7$model$livdep)
G5B7_r

screenreg(list(G5B1_r,G5B2_r,G5B3_r,G5B4_r,G5B5_r,G5B6_r,G5B7_r),
          custom.model.names = c("DD_firm1","DD_firm0","DDD_firm","DD_sector1","DD_sector0","DDD_sector","DDD_firm_in_occ1"),
          omit.coef = "(livdep)|(age)|(CSE)|(ddipl)|(year)|(male)|(hhld)",
          stars = c(0.01, 0.05, 0.1),digits = 4)
htmlreg(list(G5B1_r,G5B2_r,G5B3_r,G5B4_r,G5B5_r,G5B6_r,G5B7_r),
        custom.model.names = c("DD_firm1","DD_firm0","DDD_firm","DD_sector1","DD_sector0","DDD_sector","DDD_firm_in_occ1"),
        omit.coef = "(livdep)|(age)|(CSE)|(ddipl)|(year)|(male)|(hhld)",
        stars = c(0.01, 0.05, 0.1),digits = 4,file="tableG5B.html")
screenreg(list(G5B1,G5B2,G5B3,G5B4,G5B5,G5B6,G5B7),
          custom.model.names = c("DD_firm1","DD_firm0","DDD_firm","DD_sector1","DD_sector0","DDD_sector","DDD_firm_in_occ1"),
          omit.coef = "(livdep)|(age)|(CSE)|(ddipl)|(year)|(male)|(hhld)",
          stars = c(0.01, 0.05, 0.1),digits = 4)
htmlreg(list(G5B1,G5B2,G5B3,G5B4,G5B5,G5B6,G5B7),
        custom.model.names = c("DD_firm1","DD_firm0","DDD_firm","DD_sector1","DD_sector0","DDD_sector","DDD_firm_in_occ1"),
        omit.coef = "(livdep)|(age)|(CSE)|(ddipl)|(year)|(male)|(hhld)",
        stars = c(0.01, 0.05, 0.1),digits = 4,file="tableG5B_ols.html")
screenreg(list(G5B1_r,G5B2_r,G5B3_r,G5B4_r,G5B5_r,G5B6_r,G5B7_r),
          custom.model.names = c("DD_firm1","DD_firm0","DDD_firm","DD_sector1","DD_sector0","DDD_sector","DDD_firm_in_occ1"),
          stars = c(0.01, 0.05, 0.1),digits = 4)
htmlreg(list(G5B1_r,G5B2_r,G5B3_r,G5B4_r,G5B5_r,G5B6_r,G5B7_r),
        custom.model.names = c("DD_firm1","DD_firm0","DDD_firm","DD_sector1","DD_sector0","DDD_sector","DDD_firm_in_occ1"),
        stars = c(0.01, 0.05, 0.1),digits = 4,file="tableG5B_full.html")

#Removing results for liberating RAM
rm(G5B1,G5B2,G5B3,G5B4,G5B5,G5B6,G5B7)


############################################
############################################
#TABLE GA1. Descriptive statistics
#############################################
#############################################

des_mean<-
  rbind(tapply(e$us_hours[e$f1==1],e$alsacemo[e$f1==1],mean,na.rm=TRUE),
        tapply(e$us_hours[e$f3==1],e$alsacemo[e$f3==1],mean,na.rm=TRUE),
        tapply(e$lw_hours[e$f3==1],e$alsacemo[e$f3==1],mean,na.rm=TRUE),        
        tapply(e$us_hours[e$f3==1 & e$year==2003 & e$DATDEB %in% c("20031222","20030414")],e$alsacemo[e$f3==1 & e$year==2003 & e$DATDEB %in% c("20031222","20030414")],mean,na.rm=TRUE),          
        tapply(e$lw_hours[e$f3==1 & e$year==2003 & e$DATDEB %in% c("20031222","20030414")],e$alsacemo[e$f3==1 & e$year==2003 & e$DATDEB %in% c("20031222","20030414")],mean,na.rm=TRUE),        
        tapply(e$t_firm[e$f3==1],e$alsacemo[e$f3==1],mean,na.rm=TRUE),                        
        tapply(e$t_sector[e$f3==1],e$alsacemo[e$f3==1],mean,na.rm=TRUE),                
        tapply(e$t_occ[e$f3==1],e$alsacemo[e$f3==1],mean,na.rm=TRUE),        
        tapply(e$t_ind[e$f3==1],e$alsacemo[e$f3==1],mean,na.rm=TRUE),
        tapply(e$age1524[e$f3==1],e$alsacemo[e$f3==1],mean,na.rm=TRUE),
        tapply(e$age2539[e$f3==1],e$alsacemo[e$f3==1],mean,na.rm=TRUE),
        tapply(e$age4049[e$f3==1],e$alsacemo[e$f3==1],mean,na.rm=TRUE),        
        tapply(e$age5059[e$f3==1],e$alsacemo[e$f3==1],mean,na.rm=TRUE),        
        tapply(e$age60pl[e$f3==1],e$alsacemo[e$f3==1],mean,na.rm=TRUE),        
        tapply(e$male[e$f3==1],e$alsacemo[e$f3==1],mean,na.rm=TRUE),        
        tapply(e$hhldsize[e$f3==1],e$alsacemo[e$f3==1],mean,na.rm=TRUE),        
        tapply(e$ddipl1[e$f3==1],e$alsacemo[e$f3==1],mean,na.rm=TRUE),                                
        tapply(e$ddipl3[e$f3==1],e$alsacemo[e$f3==1],mean,na.rm=TRUE),        
        tapply(e$ddipl4[e$f3==1],e$alsacemo[e$f3==1],mean,na.rm=TRUE),        
        tapply(e$ddipl5[e$f3==1],e$alsacemo[e$f3==1],mean,na.rm=TRUE),        
        tapply(e$ddipl6[e$f3==1],e$alsacemo[e$f3==1],mean,na.rm=TRUE),        
        tapply(e$ddipl7[e$f3==1],e$alsacemo[e$f3==1],mean,na.rm=TRUE),
        tapply(e$ddipl9[e$f3==1],e$alsacemo[e$f3==1],mean,na.rm=TRUE),  
        tapply(e$employed,e$alsacemo,mean,na.rm=TRUE),
        tapply(e$unemploy[e$act3 %in% c("1","2")],e$alsacemo[e$act3 %in% c("1","2")],mean,na.rm=TRUE),
        tapply(e$hwage[e$f3==1],e$alsacemo[e$f3==1],mean,na.rm=TRUE),
        tapply(e$lhwage[e$f3==1],e$alsacemo[e$f3==1],mean,na.rm=TRUE))


des_sd<-
  rbind(tapply(e$us_hours[e$f1==1],e$alsacemo[e$f1==1],sd,na.rm=TRUE),
        tapply(e$us_hours[e$f3==1],e$alsacemo[e$f3==1],sd,na.rm=TRUE),
        tapply(e$lw_hours[e$f3==1],e$alsacemo[e$f3==1],sd,na.rm=TRUE),        
        tapply(e$us_hours[e$f3==1 & e$year==2003 & e$DATDEB %in% c("20031222","20030414")],e$alsacemo[e$f3==1 & e$year==2003 & e$DATDEB %in% c("20031222","20030414")],sd,na.rm=TRUE),          
        tapply(e$lw_hours[e$f3==1 & e$year==2003 & e$DATDEB %in% c("20031222","20030414")],e$alsacemo[e$f3==1 & e$year==2003 & e$DATDEB %in% c("20031222","20030414")],sd,na.rm=TRUE),        
        tapply(e$t_firm[e$f3==1],e$alsacemo[e$f3==1],sd,na.rm=TRUE),                        
        tapply(e$t_sector[e$f3==1],e$alsacemo[e$f3==1],sd,na.rm=TRUE),                
        tapply(e$t_occ[e$f3==1],e$alsacemo[e$f3==1],sd,na.rm=TRUE),        
        tapply(e$t_ind[e$f3==1],e$alsacemo[e$f3==1],sd,na.rm=TRUE),
        tapply(e$age1524[e$f3==1],e$alsacemo[e$f3==1],sd,na.rm=TRUE),
        tapply(e$age2539[e$f3==1],e$alsacemo[e$f3==1],sd,na.rm=TRUE),
        tapply(e$age4049[e$f3==1],e$alsacemo[e$f3==1],sd,na.rm=TRUE),        
        tapply(e$age5059[e$f3==1],e$alsacemo[e$f3==1],sd,na.rm=TRUE),        
        tapply(e$age60pl[e$f3==1],e$alsacemo[e$f3==1],sd,na.rm=TRUE),        
        tapply(e$male[e$f3==1],e$alsacemo[e$f3==1],sd,na.rm=TRUE),        
        tapply(e$hhldsize[e$f3==1],e$alsacemo[e$f3==1],sd,na.rm=TRUE),        
        tapply(e$ddipl1[e$f3==1],e$alsacemo[e$f3==1],sd,na.rm=TRUE),                                
        tapply(e$ddipl3[e$f3==1],e$alsacemo[e$f3==1],sd,na.rm=TRUE),        
        tapply(e$ddipl4[e$f3==1],e$alsacemo[e$f3==1],sd,na.rm=TRUE),        
        tapply(e$ddipl5[e$f3==1],e$alsacemo[e$f3==1],sd,na.rm=TRUE),        
        tapply(e$ddipl6[e$f3==1],e$alsacemo[e$f3==1],sd,na.rm=TRUE),        
        tapply(e$ddipl7[e$f3==1],e$alsacemo[e$f3==1],sd,na.rm=TRUE),
        tapply(e$ddipl9[e$f3==1],e$alsacemo[e$f3==1],sd,na.rm=TRUE),        
        tapply(e$employed,e$alsacemo,sd,na.rm=TRUE),
        tapply(e$unemploy[e$act3 %in% c("1","2")],e$alsacemo[e$act3 %in% c("1","2")],sd,na.rm=TRUE),
        tapply(e$hwage[e$f3==1],e$alsacemo[e$f3==1],sd,na.rm=TRUE),
        tapply(e$lhwage[e$f3==1],e$alsacemo[e$f3==1],sd,na.rm=TRUE))

des_n<-
  rbind(tapply(!is.na(e$us_hours[e$f1==1]),e$alsacemo[e$f1==1],sum,na.rm=TRUE),
        tapply(!is.na(e$us_hours[e$f3==1]),e$alsacemo[e$f3==1],sum,na.rm=TRUE),
        tapply(!is.na(e$lw_hours[e$f3==1]),e$alsacemo[e$f3==1],sum,na.rm=TRUE),        
        tapply(!is.na(e$us_hours[e$f3==1 & e$year==2003 & e$DATDEB %in% c("20031222","20030414")]),e$alsacemo[e$f3==1 & e$year==2003 & e$DATDEB %in% c("20031222","20030414")],sum,na.rm=TRUE),          
        tapply(!is.na(e$lw_hours[e$f3==1 & e$year==2003 & e$DATDEB %in% c("20031222","20030414")]),e$alsacemo[e$f3==1 & e$year==2003 & e$DATDEB %in% c("20031222","20030414")],sum,na.rm=TRUE),        
        tapply(!is.na(e$t_firm[e$f3==1]),e$alsacemo[e$f3==1],sum,na.rm=TRUE),                        
        tapply(!is.na(e$t_sector[e$f3==1]),e$alsacemo[e$f3==1],sum,na.rm=TRUE),        
        tapply(!is.na(e$t_occ[e$f3==1]),e$alsacemo[e$f3==1],sum,na.rm=TRUE),                
        tapply(!is.na(e$t_ind[e$f3==1]),e$alsacemo[e$f3==1],sum,na.rm=TRUE),
        tapply(!is.na(e$age1524[e$f3==1]),e$alsacemo[e$f3==1],sum,na.rm=TRUE),
        tapply(!is.na(e$age2539[e$f3==1]),e$alsacemo[e$f3==1],sum,na.rm=TRUE),
        tapply(!is.na(e$age4049[e$f3==1]),e$alsacemo[e$f3==1],sum,na.rm=TRUE),        
        tapply(!is.na(e$age5059[e$f3==1]),e$alsacemo[e$f3==1],sum,na.rm=TRUE),        
        tapply(!is.na(e$age60pl[e$f3==1]),e$alsacemo[e$f3==1],sum,na.rm=TRUE),        
        tapply(!is.na(e$male[e$f3==1]),e$alsacemo[e$f3==1],sum,na.rm=TRUE),        
        tapply(!is.na(e$hhldsize[e$f3==1]),e$alsacemo[e$f3==1],sum,na.rm=TRUE),        
        tapply(!is.na(e$ddipl1[e$f3==1]),e$alsacemo[e$f3==1],sum,na.rm=TRUE),                                
        tapply(!is.na(e$ddipl3[e$f3==1]),e$alsacemo[e$f3==1],sum,na.rm=TRUE),        
        tapply(!is.na(e$ddipl4[e$f3==1]),e$alsacemo[e$f3==1],sum,na.rm=TRUE),        
        tapply(!is.na(e$ddipl5[e$f3==1]),e$alsacemo[e$f3==1],sum,na.rm=TRUE),        
        tapply(!is.na(e$ddipl6[e$f3==1]),e$alsacemo[e$f3==1],sum,na.rm=TRUE),        
        tapply(!is.na(e$ddipl7[e$f3==1]),e$alsacemo[e$f3==1],sum,na.rm=TRUE),
        tapply(!is.na(e$ddipl9[e$f3==1]),e$alsacemo[e$f3==1],sum,na.rm=TRUE),        
        tapply(!is.na(e$employed),e$alsacemo,sum,na.rm=TRUE),
        tapply(!is.na(e$unemploy[e$act3 %in% c("1","2")]),e$alsacemo[e$act3 %in% c("1","2")],sum,na.rm=TRUE),
        tapply(!is.na(e$hwage[e$f3==1]),e$alsacemo[e$f3==1],sum,na.rm=TRUE),
        tapply(!is.na(e$lhwage[e$f3==1]),e$alsacemo[e$f3==1],sum,na.rm=TRUE))

des<-cbind(des_mean,des_sd,des_n)
colnames(des)<-c("R.Fr. mean","Als.M mean","R.Fr. sd","Als.M sd","R.Fr. n","Als.M n")
rownames(des)<-c("us_hours_all",
                 "us_hours_ft",
                 "lw_hours_ft",
                 "us_hours_w",
                 "lw_hours_w",
                 "t_firm",
                 "t_sector",
                 "t_occ",
                 "t_ind",
                 "age1524",
                 "age2539",
                 "age4049",
                 "age5059",
                 "age60pl",
                 "male",
                 "hhldsize",
                 "ddipl1",
                 "ddipl3",
                 "ddipl4",
                 "ddipl5",
                 "ddipl6",
                 "ddipl7",
                 "ddipl9",                 
                 "employed",
                 "unemploy",
                 "hwage",
                 "lhwage")

round(des[,c(2,4,6,1,3,5)],3)


#############################################
#############################################
#Table GA2. T_firm description
#############################################
#############################################

GA2<-data.frame(tapply(is.na(e$t_firm[e$f3==1])==TRUE,e$year[e$f3==1],mean,na.rm=TRUE),
                 tapply(e$t_firm[e$f3==1] %in% 0,e$year[e$f3==1],mean,na.rm=TRUE),
                 tapply(e$t_firm[e$f3==1] %in% 1,e$year[e$f3==1],mean,na.rm=TRUE),
                tapply(e$t_firm[e$f3==1],e$year[e$f3==1],mean,na.rm=TRUE),                
                 tapply(e$tn20[e$f3==1]>=0,e$year[e$f3==1],sum,na.rm=TRUE))

colnames(GA2)<-c("Missing","TN<20","TN>19","TN>19WMiss","Obs")
GA2


#############################################
#############################################
#Figures GA1 to GA3
#############################################
#############################################


FGA1a<-tapply(e$us_hours[e$f3==1  ],list(e$period[e$f3==1 ],e$livreg[e$f3==1 ]),mean,na.rm=TRUE)
FGA2a<-tapply(e$us_hours[e$f3==1 & e$t_occ==1 ],list(e$period[e$f3==1 & e$t_occ==1],e$livreg[e$f3==1 & e$t_occ==1]),mean,na.rm=TRUE)
FGA3a<-tapply(e$us_hours[e$f3==1 & e$t_occ==1 & e$borderwo==0],list(e$period[e$f3==1 & e$t_occ==1 & e$borderwo==0],e$livreg[e$f3==1 & e$t_occ==1 & e$borderwo==0]),mean,na.rm=TRUE)

FGA1b<-tapply(e$us_hours[e$f3==1  ],list(e$year[e$f3==1 ],e$livreg[e$f3==1 ]),mean,na.rm=TRUE)
FGA2b<-tapply(e$us_hours[e$f3==1 & e$t_occ==1 ],list(e$year[e$f3==1 & e$t_occ==1],e$livreg[e$f3==1 & e$t_occ==1]),mean,na.rm=TRUE)
FGA3b<-tapply(e$us_hours[e$f3==1 & e$t_occ==1 & e$borderwo==0],list(e$year[e$f3==1 & e$t_occ==1 & e$borderwo==0],e$livreg[e$f3==1 & e$t_occ==1 & e$borderwo==0]),mean,na.rm=TRUE)

FGA1b-FGA1a[1,]
FGA2b-FGA2a[1,]
FGA3b-FGA3a[1,]


#############################################
#############################################
#Table 2. Employment effect 
#############################################
#############################################
#There was some convergence issues for probit with glm. Therefore I use LPM with R

T21<-lm(employed~factor(year)+livdep+CSE+ddipl1+ddipl3+ddipl4+ddipl5+ddipl6+ddipl9+male
                  +hhldsize+age1524+age2539+age5059+age60pl+alsacemo0102+alsacemo9900
                  ,weight=EXTRI,data=e[e$f4==1 & e$t_occ==1 ,])
T21_r<-clx(T21,1,cluster=T21$model$livdep)
T21_r

T22<-lm(employed~factor(year)+livdep+CSE+ddipl1+ddipl3+ddipl4+ddipl5+ddipl6+ddipl9+male
                  +hhldsize+age1524+age2539+age5059+age60pl+alsacemo0102+alsacemo9900
                  ,weight=EXTRI,data=e[e$f4==1 & e$t_occ==0 ,])
T22_r<-clx(T22,1,cluster=T22$model$livdep)
T22_r

T23<-lm(employed~t_occ*factor(year)+t_occ*livdep+t_occ*CSE+ddipl1
                  +ddipl3+ddipl4+ddipl5+ddipl6+ddipl9+male
                  +hhldsize+age1524+age2539+age5059+age60pl
                  +t_occ*alsacemo0102+t_occ*alsacemo9900
                  ,weight=EXTRI,data=e[e$f4==1 ,])
T23_r<-clx(T23,1,cluster=T23$model$livdep)
T23_r


T24<-lm(employed~t_occ*factor(year)+t_occ*livdep+t_occ*CSE+ddipl1
                          +ddipl3+ddipl4+ddipl5+ddipl6+ddipl9+male
                          +hhldsize+age1524+age2539+age5059+age60pl
                          +t_occ*alsacemo0102+t_occ*alsacemo9900
                          ,weight=EXTRI,data=e[e$f4==1 & e$DDIPL %in% c("1","3") ,])
T24_r<-clx(T24,1,cluster=T24$model$livdep)
T24_r

T25<-lm(employed~t_occ*factor(year)+t_occ*livdep+t_occ*CSE+ddipl1
                            +ddipl3+ddipl4+ddipl5+ddipl6+ddipl9+male
                            +hhldsize+age1524+age2539+age5059+age60pl
                            +t_occ*alsacemo0102+t_occ*alsacemo9900
                            ,weight=EXTRI,data=e[e$f4==1 & e$DDIPL %in% c("4","5","6","7") ,])
T25_r<-clx(T25,1,cluster=T25$model$livdep)
T25_r

screenreg(list(T21_r,T22_r,T23_r,T24_r,T25_r),
          custom.model.names = c("DD_occ1","DD_occ0","DDD_occ","DDD_occ_skilled","DDD_occ_unskilled"),
          omit.coef = "(livdep)|(age)|(CSE)|(ddipl)|(year)|(male)|(hhld)",
          stars = c(0.01, 0.05, 0.1),digits = 4)
htmlreg(list(T21_r,T22_r,T23_r,T24_r,T25_r),
        custom.model.names = c("DD_occ1","DD_occ0","DDD_occ","DDD_occ_skilled","DDD_occ_unskilled"),
        omit.coef = "(livdep)|(age)|(CSE)|(ddipl)|(year)|(male)|(hhld)",
        stars = c(0.01, 0.05, 0.1),digits = 4,file="table2.html")
screenreg(list(T21,T22,T23,T24,T25),
          custom.model.names = c("DD_occ1","DD_occ0","DDD_occ","DDD_occ_skilled","DDD_occ_unskilled"),
          omit.coef = "(livdep)|(age)|(CSE)|(ddipl)|(year)|(male)|(hhld)",
          stars = c(0.01, 0.05, 0.1),digits = 4)
htmlreg(list(T21,T22,T23,T24,T25),
        custom.model.names = c("DD_occ1","DD_occ0","DDD_occ","DDD_occ_skilled","DDD_occ_unskilled"),
        omit.coef = "(livdep)|(age)|(CSE)|(ddipl)|(year)|(male)|(hhld)",
        stars = c(0.01, 0.05, 0.1),digits = 4,file="table2_norob.html")

screenreg(list(T21_r,T22_r,T23_r,T24_r,T25_r),
          custom.model.names = c("DD_occ1","DD_occ0","DDD_occ","DDD_occ_skilled","DDD_occ_unskilled"),
          stars = c(0.01, 0.05, 0.1),digits = 4)
htmlreg(list(T21_r,T22_r,T23_r,T24_r,T25_r),
        custom.model.names = c("DD_occ1","DD_occ0","DDD_occ","DDD_occ_skilled","DDD_occ_unskilled"),
        stars = c(0.01, 0.05, 0.1),digits = 4,file="table2_full.html")



#Removing results for liberating RAM
rm(T21)
rm(T22)
rm(T23)
rm(T24)
rm(T25)

#VARIANT On UNSKILLED

DD_unskilled<-lm(employed~factor(year)+livdep+CSE+ddipl1+ddipl3+ddipl4+ddipl5+ddipl6+ddipl9+male
                  +hhldsize+age1524+age2539+age5059+age60pl+alsacemo0102+alsacemo9900
                  ,weight=EXTRI,data=e[e$f4==1 & e$t_occ==1 & e$DDIPL %in% c("4","5","6","7"),])
DD_unskilled_r<-clx(DD_unskilled,1,cluster=DD_unskilled$model$livdep)
DD_unskilled_r


#############################################
#############################################
#Table 3. Unemployment effect 
#############################################
#############################################

T31<-lm(unemploy~factor(year)+livdep+CSE+ddipl1+ddipl3+ddipl4+ddipl5+ddipl6+ddipl9+male
         +hhldsize+age1524+age2539+age5059+age60pl+alsacemo0102+alsacemo9900
         ,weight=EXTRI,data=e[e$f4==1 & e$t_occ==1 ,])
T31_r<-clx(T31_r,1,cluster=T31$model$livdep)
T31_r

T32<-lm(unemploy~factor(year)+livdep+CSE+ddipl1+ddipl3+ddipl4+ddipl5+ddipl6+ddipl9+male
         +hhldsize+age1524+age2539+age5059+age60pl+alsacemo0102+alsacemo9900
         ,weight=EXTRI,data=e[e$f4==1 & e$t_occ==0 ,])
T32_r<-clx(T32_r,1,cluster=T32$model$livdep)
T32_r

T33<-lm(unemploy~t_occ*factor(year)+t_occ*livdep+t_occ*CSE+ddipl1
         +ddipl3+ddipl4+ddipl5+ddipl6+ddipl9+male
         +hhldsize+age1524+age2539+age5059+age60pl
         +t_occ*alsacemo0102+t_occ*alsacemo9900
         ,weight=EXTRI,data=e[e$f4==1 ,])
T33_r<-clx(T33_r,1,cluster=T33$model$livdep)
T33_r


T34<-lm(unemploy~t_occ*factor(year)+t_occ*livdep+t_occ*CSE+ddipl1
         +ddipl3+ddipl4+ddipl5+ddipl6+ddipl9+male
         +hhldsize+age1524+age2539+age5059+age60pl
         +t_occ*alsacemo0102+t_occ*alsacemo9900
         ,weight=EXTRI,data=e[e$f4==1 & e$DDIPL %in% c("1","3") ,])
T34_r<-clx(T34_r,1,cluster=T34_r$model$livdep)
T34_r

T35<-lm(unemploy~t_occ*factor(year)+t_occ*livdep+t_occ*CSE+ddipl1
         +ddipl3+ddipl4+ddipl5+ddipl6+ddipl9+male
         +hhldsize+age1524+age2539+age5059+age60pl
         +t_occ*alsacemo0102+t_occ*alsacemo9900
         ,weight=EXTRI,data=e[e$f4==1 & e$DDIPL %in% c("4","5","6","7") ,])
T35_r<-clx(T35_r,1,cluster=T35$model$livdep)
T35_r

screenreg(list(T31_r,T32_r,T33_r,T34_r,T35_r),
          custom.model.names = c("DD_occ1","DD_occ0","DDD_occ","DDD_occ_skilled","DDD_occ_unskilled"),
          omit.coef = "(livdep)|(age)|(CSE)|(ddipl)|(year)|(male)|(hhld)",
          stars = c(0.01, 0.05, 0.1),digits = 4)
htmlreg(list(T31_r,T32_r,T33_r,T34_r,T35_r),
        custom.model.names = c("DD_occ1","DD_occ0","DDD_occ","DDD_occ_skilled","DDD_occ_unskilled"),
        omit.coef = "(livdep)|(age)|(CSE)|(ddipl)|(year)|(male)|(hhld)",
        stars = c(0.01, 0.05, 0.1),digits = 4,file="table3.html")
screenreg(list(T31,T32,T33,T34,T35),
          custom.model.names = c("DD_occ1","DD_occ0","DDD_occ","DDD_occ_skilled","DDD_occ_unskilled"),
          omit.coef = "(livdep)|(age)|(CSE)|(ddipl)|(year)|(male)|(hhld)",
          stars = c(0.01, 0.05, 0.1),digits = 4)
htmlreg(list(T31,T32,T33,T34,T35),
        custom.model.names = c("DD_occ1","DD_occ0","DDD_occ","DDD_occ_skilled","DDD_occ_unskilled"),
        omit.coef = "(livdep)|(age)|(CSE)|(ddipl)|(year)|(male)|(hhld)",
        stars = c(0.01, 0.05, 0.1),digits = 4,file="table3_norob.html")

screenreg(list(T31_r,T32_r,T33_r,T34_r,T35_r),
          custom.model.names = c("DD_occ1","DD_occ0","DDD_occ","DDD_occ_skilled","DDD_occ_unskilled"),
          stars = c(0.01, 0.05, 0.1),digits = 4)
htmlreg(list(T31_r,T32_r,T33_r,T34_r,T35_r),
        custom.model.names = c("DD_occ1","DD_occ0","DDD_occ","DDD_occ_skilled","DDD_occ_unskilled"),
        stars = c(0.01, 0.05, 0.1),digits = 4,file="table3_full.html")

#Removing results for liberating RAM
rm(T31)
rm(T32)
rm(T33)
rm(T34)
rm(T35)        
        


