*************************************
* RAW DATA created with SAS software
* cf. Append_Main.sas
************************************
clear
set more off
set matsize 1000
import sasxport "D:\Olivier\Documents\Universite\data\Emploi\Jole_2009_Data\LFS_9603_raw.xpt"
*import sasxport "C:\Users\olivier.godechot\Documents\Universite\Data\Emploi\Jole_2009_Data\LFS_9603_raw.xpt.xpt"

describe

*Conversion of factor to numeric variable
destring hh, gen (hh_n) force
destring efen98, gen (efen98_n) force
destring ag, gen (ag_n) force
destring age, gen (age_n) force
destring ht, gen (ht_n) force
destring cse, gen (cse_n) force

destring dea, gen (year2)
replace year2=2003 if annee=="2003"
gen year3=(year2<=100)*(year2+1900)+(year2>100)*(year2)


*Usual working hours
gen us_hours=hh_n
replace us_hours=hhc if year==2003

 
*Last week working hours
gen lw_hours=ht_n
replace lw_hours=empnbh if year==2003

*Hourly wage
replace salred=salred*6.55957 if year==2003
gen hwage=salred/(4.34*min(us_hours,48)) if us_hours>0 & missing(us_hours)==0
gen lhwage=log(hwage) if hwage>0 & missing(hwage)==0

*Full time 
gen fulltim=(inlist(duhab,"4","5","6","7"))

*gender
gen female=(sexe=="2"  | s=="2")
gen male=1-female

*civil servant
gen public=(chpub == "2")
replace public=inlist(chpub,"1","2","3") if year==2003

*wage earner
gen wageearn=(st == "2")
replace wageearn=(stat2 == "2") if year==2003


*definition of living department (department fixed effect)
gen livdep=dep
replace livdep="20" if inlist(livdep,"2A","2B")
destring livdep, replace

*definition of working department (department fixed effect)
gen workdep=depeta if year<2003
replace workdep=deparc if year==2003
replace workdep="20" if inlist(workdep,"2A","2B")
destring workdep, replace
replace workdep=livdep if missing(workdep) 

* Border workers
gen borderwo=(1-(peta=="10" | peta==""))

****establish the correspondance with the border country:
* Here I follow exactly the program for the JOLE 2009 article; 
* Other decision could be done for some departments like Moselle (matching with Luxembourg); 
* or Haut Rhin (matching with Switzerland rather than with Germany) and similarly Aisne (02) could be included in the ; 
* list and matched with Belgium; 
* Note that the STATA code finally attributes 74 to Italy
gen country="Belgium" if livdep==59|livdep==08|livdep==55
replace country="Luxembourg" if livdep==54
replace country="Germany" if livdep==57|livdep==67|livdep==68
replace country="Switzerland" if livdep==90|livdep==25|livdep==39|livdep==1|livdep==74
replace country="Italy" if livdep==73|livdep==74|livdep==4|livdep==5|livdep==6
replace country="Spain" if livdep==66|livdep==9|livdep==31|livdep==65|livdep==64
replace country="No border" if missing(country)==1

* Border Department * Growth
* Data extracted on 24 Sep 2016 10:06 UTC (GMT) from OECD.Stat;
* http://stats.oecd.org/index.aspx?DatasetCode=EO; 
gen bordergdp=0 if country=="No border"
replace bordergdp=1.58960805579247 if country=="Belgium" & year==1996
replace bordergdp=3.7098969741779 if country=="Belgium" & year==1997
replace bordergdp=1.97648077819975 if country=="Belgium" & year==1998
replace bordergdp=3.56273663647085 if country=="Belgium" & year==1999
replace bordergdp=3.64016036893688 if country=="Belgium" & year==2000
replace bordergdp=0.805943529168277 if country=="Belgium" & year==2001
replace bordergdp=1.77955176068139 if country=="Belgium" & year==2002
replace bordergdp=0.774248667313357 if country=="Belgium" & year==2003
replace bordergdp=0.853803107702814 if country=="Germany" & year==1996
replace bordergdp=1.90478756470841 if country=="Germany" & year==1997
replace bordergdp=1.7755820082395 if country=="Germany" & year==1998
replace bordergdp=1.84519905837833 if country=="Germany" & year==1999
replace bordergdp=3.19740195821453 if country=="Germany" & year==2000
replace bordergdp=1.83767366339264 if country=="Germany" & year==2001
replace bordergdp=0.018796971665527 if country=="Germany" & year==2002
replace bordergdp=-0.730261487285155 if country=="Germany" & year==2003
replace bordergdp=1.52021815057823 if country=="Luxembourg" & year==1996
replace bordergdp=5.95023422423793 if country=="Luxembourg" & year==1997
replace bordergdp=6.48430414707796 if country=="Luxembourg" & year==1998
replace bordergdp=8.42348341729952 if country=="Luxembourg" & year==1999
replace bordergdp=8.4138511615165 if country=="Luxembourg" & year==2000
replace bordergdp=2.14738895086324 if country=="Luxembourg" & year==2001
replace bordergdp=3.62592944338009 if country=="Luxembourg" & year==2002
replace bordergdp=1.41294747363995 if country=="Luxembourg" & year==2003
replace bordergdp=2.67477982295753 if country=="Spain" & year==1996
replace bordergdp=3.68947185154924 if country=="Spain" & year==1997
replace bordergdp=4.30597844697085 if country=="Spain" & year==1998
replace bordergdp=4.48477443037206 if country=="Spain" & year==1999
replace bordergdp=5.28922090746535 if country=="Spain" & year==2000
replace bordergdp=4.00106922543372 if country=="Spain" & year==2001
replace bordergdp=2.87976212105771 if country=="Spain" & year==2002
replace bordergdp=3.18757147564503 if country=="Spain" & year==2003
replace bordergdp=0.553143472905909 if country=="Switzerland" & year==1996
replace bordergdp=2.28249395074228 if country=="Switzerland" & year==1997
replace bordergdp=2.86759553716691 if country=="Switzerland" & year==1998
replace bordergdp=1.59413007109722 if country=="Switzerland" & year==1999
replace bordergdp=4.1730931201534 if country=="Switzerland" & year==2000
replace bordergdp=1.45704410800672 if country=="Switzerland" & year==2001
replace bordergdp=0.147402714479676 if country=="Switzerland" & year==2002
replace bordergdp=0.080114046598927 if country=="Switzerland" & year==2003
replace bordergdp=1.00012290887587 if country=="Italy" & year==1996
replace bordergdp=1.96767328011084 if country=="Italy" & year==1997
replace bordergdp=1.45619718946013 if country=="Italy" & year==1998
replace bordergdp=1.5085997667673 if country=="Italy" & year==1999
replace bordergdp=3.96835161235477 if country=="Italy" & year==2000
replace bordergdp=1.58146107576628 if country=="Italy" & year==2001
replace bordergdp=0.24728101400427 if country=="Italy" & year==2002
replace bordergdp=0.238103105481728 if country=="Italy" & year==2003

*Borderding countries dummy including Aisne
gen country1=1-(country=="No border")
*Adding AISNE (very short border with Belgium)
replace country1=1 if livdep==2


*Redefinition of living region => Moselle in Alsace
gen livreg=rg if year<2003
replace livreg=reg if missing(livreg) & year==2003
replace livreg="42" if livdep==57
destring livreg, replace
replace livreg=92 if livreg==93 
replace livreg=92 if livreg==94

*Alsace Moselle 
* Living in Alsace-Moselle
gen alsacemo=(inlist (livdep,57,67,68))

* Working or Living in Alsace-Moselle
gen alsacemo_o=(inlist (workdep,57,67,68))

*Size of firm
gen efen_n=efen
replace efen_n=efen98_n if year==1998
replace efen_n=. if efen_n==999999
gen efen99=(missing(efen_n)==1 | efen_n==999999)
gen efen20=(efen_n>19 & efen_n<999999 & missing(efen_n)==0)
gen efen20w=efen20  if efen99==0
gen efen20e=(efen_n>19)

gen tn20=(inlist(tn,"5","6","7","8","9"))
gen tn99=(tn == "")
gen tn0=(tn=="0")
gen tn99b=(tn == "" | tn=="0")
gen tn20w=tn20 if tn99==0
gen tn20wb=tn20 if tn99==0 & tn0==0
gen tn20e=tn20+tn99b
gen tn20e2=tn20+tn99


gen nbsalb20=(inlist(nbsalb,"5","6","7","8","9"))
gen nbsalb0=(inlist(nbsalb,"1"))
gen nbsalb99=(inlist(nbsalb,"","99"))
gen nbsalb99b=(inlist(nbsalb,"","99","1"))
gen nbsalb20w=nbsalb20 if nbsalb99==0
gen nbsalb20wb=nbsalb20 if nbsalb99b==0

*targeted occupation
gen t_occ=(cse_n>31 & cse_n<70 &  cse !="34" & cse !="44" & cse !="42" & cse !="56")

*targeted firm 
gen t_firm=1 if public==1
replace t_firm=1 if t_firm==. & year==2003 & efen20==1 & efen99==0
replace t_firm=0 if t_firm==. & year==2003 & efen20==0 & efen99==0
replace t_firm=1 if t_firm==. & year==2003 & efen99==1 & (inlist(nbsalb,"5","6","7","8","9")) 
replace t_firm=0 if t_firm==. & year==2003 & efen99==1 & (inlist(nbsalb,"0","1","2","3","4")) 
replace t_firm=1 if t_firm==. & year<2003 & (inlist(tn,"5","6","7","8","9"))
replace t_firm=0 if t_firm==. & year<2003 & year>1997 & (inlist(tn,"0","1","2","3","4"))
replace t_firm=0 if t_firm==. & year<1998 & (inlist(tn,"1","2","3","4"))
replace t_firm=0 if t_firm==. & wageearn==0

*targeted firm with inclusions of missing in small firms
gen t_firmb=t_firm
replace t_firmb=0 if t_firm==.
gen t_firm99=(t_firm==.)
gen t_firm0=(t_firm==0)

*targeted sector
gen sector=nafg36
replace sector=nafg36u if  year==2003
gen t_sector=(inlist(sector,"F5","J3","P1","H0"))

*targeted individuals
gen t_ind=((t_occ+t_firm+t_sector)>=3)
replace t_ind=. if t_firm==.

*age with numeric variable
gen agen=ag_n if year<2003
replace agen=age_n if year==2003
gen age1524=(15<=agen & agen<=24)
gen age2539=(25<=agen & agen<=39)
gen age4049=(40<=agen & agen<=49)
gen age5059=(50<=agen & agen<=59)
gen age60pl=(60<=agen & agen<108)

*age with AG5
*tab ag5, gen(ag5dum)
gen ag5dum1=age1524
gen ag5dum2=age2539
gen ag5dum4=age4049
gen ag5dum5=age5059
gen ag5dum6=age60pl

*household size 
gen hhldsize=np if year<2003
replace hhldsize=nbinde if year==2003
replace hhldsize=5 if hhldsize>=5

*diploma 
gen ddipl1=(ddipl == "1")
gen ddipl3=(ddipl == "3")
gen ddipl4=(ddipl == "4")
gen ddipl5=(ddipl == "5")
gen ddipl6=(ddipl == "6")
gen ddipl7=(ddipl == "7")
gen ddipl9=(ddipl == "")

*skilled
gen skilled=(ddipl=="1" | ddipl=="3")
gen skilled_o=(ddipl=="1" | ddipl=="3" | ddipl=="4")

*period
gen per9900=(year == 1999 | year == 2000)
gen per0102=(year == 2001 | year == 2002)
gen per03=(year == 2003)

gen period=19968 if year<1999
replace period=19990 if year>1998 & year<2001
replace period=20012 if year>2000 & year<2003
replace period=20033 if year>2002


*employment
gen act3=act
replace act3=acteu if year==2003
gen employed=(act3 == "1")
gen unemploy=(act3 == "2") if inlist(act3,"1","2")

gen act7_n=act7
replace act7_n=acteu6 if year==2003
destring act7_n, replace

				 
gen all=1

*Interaction variables
*alsacemo*periods
gen alsacemo9900=alsacemo*per9900
gen alsacemo0102=alsacemo*per0102
gen alsacemo03=alsacemo*per03

*Other interactions 
gen t_occyear=10000*t_occ+year
gen t_occlivdep=100*t_occ+livdep 
gen t_occcse_n=100*t_occ+cse_n 
gen t_occalsacemo9900=t_occ*alsacemo9900
gen t_occalsacemo0102=t_occ*alsacemo0102
gen t_occalsacemo03=t_occ*alsacemo03
gen t_indyear=10000*t_ind+year
gen t_indlivdep=100*t_ind+livdep 
gen t_indcse_n=100*t_ind+cse_n 
gen t_indalsacemo9900=t_ind*alsacemo9900
gen t_indalsacemo0102=t_ind*alsacemo0102
gen t_indalsacemo03=t_ind*alsacemo03
gen t_firmyear=10000*t_firm+year
gen t_firmlivdep=100*t_firm+livdep 
gen t_firmcse_n=100*t_firm+cse_n 
gen t_firmalsacemo9900=t_firm*alsacemo9900
gen t_firmalsacemo0102=t_firm*alsacemo0102
gen t_firmalsacemo03=t_firm*alsacemo03
gen t_sectoryear=10000*t_sector+year
gen t_sectorlivdep=100*t_sector+livdep 
gen t_sectorcse_n=100*t_sector+cse_n 
gen t_sectoralsacemo9900=t_sector*alsacemo9900
gen t_sectoralsacemo0102=t_sector*alsacemo0102
gen t_sectoralsacemo03=t_sector*alsacemo03
gen livregperiod=100000*livreg+period
gen livregyear=10000*livreg+year






*fields
*field all workers
gen f1=((act7_n==1|act7_n==3|act7_n==4))

*field all workers full time
gen f2=(f1 == 1 & fulltim == 1)

*field all workers full time and department, household and valid
gen f3=(f2==1 & missing(cse_n)==0 &  missing(us_hours)==0 ///
 & missing(hhldsize)==0 & missing(livdep)==0 & missing(ag5)==0 & extri !=. & extri !=0)

*field all workers full time and department, household and valid & not working abroad
gen f3b=(f3==1 & borderwo==0)

*field all individuals active & inactive and department valid (Table 2)
gen f4=(cse_n>9  & cse_n<70 &  missing(hhldsize)==0 & missing(livdep)==0 & year<2003 ///
	& extri !=. & extri !=0)

*field all individuals active & inactive and department valid plus year 2003 (Table 2)
gen f4b=(cse_n>9  & cse_n<70 &  missing(hhldsize)==0 & missing(livdep)==0 ///
	& extri !=. & extri !=0)

*field all individuals active and department valid (Table 3)
gen f5=(f4==1 & (act7_n==1|act7_n==3|act7_n==4))

*field all individuals active and department valid plus year 2003 (Table 3)
gen f5b=(f4b==1 & (act7_n==1|act7_n==3|act7_n==4))

tab country
**************************************************************************************
* Table G1. Descriptive statics size of firms
**************************************************************************************
tabstat efen_n efen99 efen20 efen20w if f3==1, by(year) s(me)
tabstat efen_n if f3==1, by(year) s(sd)
tabstat tn99 tn0 tn99b tn20 tn20wb if f3==1 & year<2003, by(year) s(me)
tabstat tn99 if f3==1, by(year) st(co) /*Number of observations*/
tabstat nbsalb99 nbsalb0 nbsalb99b nbsalb20 nbsalb20wb if f3==1 & year==2003, by(year) s(me)



**************************************************************************************
* Table G2. Replication of TABLE A2 model 1-3 with various firm definitions
**************************************************************************************
regress us_hours i.year i.livdep i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* ///
		alsacemo03 alsacemo0102 alsacemo9900 if f3==1 & tn20w==1 & year<2003 [pweight=extri], cluster(livdep)
outreg2 using "table_G2B.xls", bdec(4) se ctitle("DD Target firm") bracket replace
outreg2 using "table_G2B_s.xls", bdec(4) se ctitle("DD Target firm") keep(alsacemo*) bracket replace

regress us_hours i.year i.livdep i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* ///
		alsacemo03 alsacemo0102 alsacemo9900 if f3==1 & tn20w==0 & year<2003 [pweight=extri], cluster(livdep)
outreg2 using "table_G2B.xls", bdec(4) se ctitle("DD control firm") bracket append
outreg2 using "table_G2B_s.xls", bdec(4) se ctitle("DD control firm") keep(alsacemo*) bracket append

regress us_hours i.year i.livdep i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* ///
		alsacemo03 alsacemo0102 alsacemo9900 if f3==1 & tn99==1 & year<2003 [pweight=extri], cluster(livdep)		
outreg2 using "table_G2B.xls", bdec(4) se ctitle("DD missing firm") bracket append
outreg2 using "table_G2B_s.xls", bdec(4) se ctitle("DD missing firm") keep(alsacemo*) bracket append
		
regress us_hours tn20w##i.year tn20w##i.livdep tn20w##i.cse_n  ddipl1 ///
		ddipl3 ddipl4 ddipl5 ddipl6 ddipl9 ///
		male hhldsize ag5dum*  ///
		alsacemo03 alsacemo0102 alsacemo9900 ///		
		tn20w##alsacemo03 tn20w##alsacemo0102 tn20w##alsacemo9900  if f3==1 & year<2003 [pweight=extri], cluster(livdep)		
outreg2 using "table_G2B.xls", bdec(4) se ctitle("DDD firm (no missing)") bracket append
outreg2 using "table_G2B_s.xls", bdec(4) se ctitle("DDD firm (no missing)") keep(alsacemo* tn20w##alsacemo*) bracket append

regress us_hours tn20##i.year tn20##i.livdep tn20##i.cse_n  ddipl1 ///
		ddipl3 ddipl4 ddipl5 ddipl6 ddipl9 ///
		male hhldsize ag5dum*  ///
		alsacemo03 alsacemo0102 alsacemo9900 ///		
		tn20##alsacemo03 tn20##alsacemo0102 tn20##alsacemo9900  if f3==1 ///
		& year<2003 [pweight=extri], cluster(livdep)				
outreg2 using "table_G2B.xls", bdec(4) se ctitle("DDD firm (with missing)") bracket append
outreg2 using "table_G2B_s.xls", bdec(4) se ctitle("DDD firm (with missing)") keep(alsacemo* tn20##alsacemo*) bracket append

regress us_hours i.year i.livdep i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* ///
		alsacemo03 alsacemo0102 alsacemo9900 if f3==1 & tn20e==1 & year<2003 [pweight=extri], cluster(livdep)
outreg2 using "table_G2B.xls", bdec(4) se ctitle("DD Target firm with missing") bracket append
outreg2 using "table_G2B_s.xls", bdec(4) se ctitle("DD Target firm with missing") keep(alsacemo*) bracket append

regress us_hours tn20e##i.year tn20e##i.livdep tn20e##i.cse_n  ddipl1 ///
		ddipl3 ddipl4 ddipl5 ddipl6 ddipl9 ///
		male hhldsize ag5dum*  ///
		alsacemo03 alsacemo0102 alsacemo9900 ///		
		tn20e##alsacemo03  tn20e##alsacemo0102 tn20e##alsacemo9900 if f3==1 ///
		& year<2003 [pweight=extri], cluster(livdep)				
outreg2 using "table_G2B.xls", bdec(4) se ctitle("DDD firm (with missing in target firm)") bracket append
outreg2 using "table_G2B_s.xls", bdec(4) se ctitle("DDD firm (with missing in target firm)") keep(alsacemo* tn20e##alsacemo*) bracket append

**************************************************************************************
* Table G3. PANEL A. REPLICATION OF TABLE 1
**************************************************************************************
regress us_hours i.year i.livdep i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* ///
		alsacemo03 alsacemo0102 alsacemo9900 if f3==1 & t_occ==1 [pweight=extri], cluster(livdep)
outreg2 using "table_1_G3A.xls", bdec(4) se ctitle("DD Target occ") bracket replace
outreg2 using "table_1_G3A_s.xls", bdec(4) se ctitle("DD Target occ") keep(alsacemo*) bracket replace

regress us_hours i.year i.livdep i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* ///
		alsacemo03 alsacemo0102 alsacemo9900 if f3==1 & t_occ==0 [pweight=extri], cluster(livdep)
outreg2 using "table_1_G3A.xls", bdec(4) se ctitle("DD Control occ") bracket append		
outreg2 using "table_1_G3A_s.xls", bdec(4) se ctitle("DD Control occ") keep(alsacemo*) bracket append		
		
regress us_hours t_occ##i.year t_occ##i.livdep t_occ##i.cse_n ddipl1 ///
		ddipl3 ddipl4 ddipl5 ddipl6 ddipl9 ///
		male hhldsize ag5dum*  ///
		alsacemo03 alsacemo0102 alsacemo9900 ///
		t_occ##alsacemo03 t_occ##alsacemo0102 t_occ##alsacemo9900  if f3==1 [pweight=extri], cluster(livdep)
outreg2 using "table_1_G3A.xls", bdec(4) se ctitle("DDD occ") bracket append		
outreg2 using "table_1_G3A_s.xls", bdec(4) se ctitle("DDD occ") keep(alsacemo* t_occ##alsacemo*) bracket append		

regress us_hours i.year i.livdep i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum*  ///
		alsacemo03 alsacemo0102 alsacemo9900 if f3==1 & t_ind==1 [pweight=extri], cluster(livdep)
outreg2 using "table_1_G3A.xls", bdec(4) se ctitle("DD Target ind") bracket append		
outreg2 using "table_1_G3A_s.xls", bdec(4) se ctitle("DD Target ind") keep(alsacemo*) bracket append		

regress us_hours i.year i.livdep i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* ///
		alsacemo03 alsacemo0102 alsacemo9900 if f3==1 & t_ind==0 [pweight=extri], cluster(livdep)
outreg2 using "table_1_G3A.xls", bdec(4) se ctitle("DD Control ind") bracket append				
outreg2 using "table_1_G3A_s.xls", bdec(4) se ctitle("DD Control ind") keep(alsacemo*) bracket append		
		
regress us_hours t_ind##i.year t_ind##i.livdep t_ind##i.cse_n  ddipl1 ///
		ddipl3 ddipl4 ddipl5 ddipl6 ddipl9 ///
		male hhldsize ag5dum*  ///
		alsacemo03 alsacemo0102 alsacemo9900 ///
		t_ind##alsacemo03 t_ind##alsacemo0102 t_ind##alsacemo9900  if f3==1 [pweight=extri], cluster(livdep)
outreg2 using "table_1_G3A.xls", bdec(4) se ctitle("DDD ind") bracket append		
outreg2 using "table_1_G3A_s.xls", bdec(4) se ctitle("DDD ind") keep(alsacemo* t_ind##alsacemo*) bracket append		

regress us_hours i.year i.livdep i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum*  ///
		alsacemo03 alsacemo0102 alsacemo9900 bordergdp if f3==1 & t_ind==1 [pweight=extri], cluster(livdep)
outreg2 using "table_1_G3A.xls", bdec(4) se ctitle("DD ind + bordergdp") bracket append		
outreg2 using "table_1_G3A_s.xls", bdec(4) se ctitle("DD ind + bordergdp") keep(alsacemo* t_ind##alsacemo* bordergdp) bracket append		

**************************************************************************************
* Table G3. PANEL B. REPLICATION OF TABLE A2
**************************************************************************************
	
regress us_hours i.year i.livdep i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* ///
		alsacemo03 alsacemo0102 alsacemo9900 if f3==1 & t_firm==1 [pweight=extri], cluster(livdep)
outreg2 using "table_A2_G3B.xls", bdec(4) se ctitle("DD Target firm") bracket replace
outreg2 using "table_A2_G3B_s.xls", bdec(4) se ctitle("DD Target firm") keep(alsacemo*) bracket replace

regress us_hours i.year i.livdep i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* ///
		alsacemo03 alsacemo0102 alsacemo9900 if f3==1 & t_firm==0 [pweight=extri], cluster(livdep)
outreg2 using "table_A2_G3B.xls", bdec(4) se ctitle("DD Control firm") bracket append		
outreg2 using "table_A2_G3B_s.xls", bdec(4) se ctitle("DD Control firm") keep(alsacemo*) bracket append		
		
regress us_hours t_firm##i.year t_firm##i.livdep t_firm##i.cse_n  ddipl1 ///
		ddipl3 ddipl4 ddipl5 ddipl6 ddipl9 ///
		male hhldsize ag5dum*  ///
		alsacemo03 alsacemo0102 alsacemo9900 ///		
		t_firm##alsacemo03 t_firm##alsacemo0102 t_firm##alsacemo9900  if f3==1 [pweight=extri], cluster(livdep)		
outreg2 using "table_A2_G3B.xls", bdec(4) se ctitle("DDD firm") bracket append		
outreg2 using "table_A2_G3B_s.xls", bdec(4) se ctitle("DDD firm") keep(alsacemo* t_firm##alsacemo*) bracket append		
		
regress us_hours i.year i.livdep i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* ///
		alsacemo03 alsacemo0102 alsacemo9900 if f3==1 & t_sector==1 [pweight=extri], cluster(livdep)
outreg2 using "table_A2_G3B.xls", bdec(4) se ctitle("DD Target sector") bracket append		
outreg2 using "table_A2_G3B_s.xls", bdec(4) se ctitle("DD Target sector") keep(alsacemo*) bracket append		

regress us_hours i.year i.livdep i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* ///
		alsacemo03 alsacemo0102 alsacemo9900 if f3==1 & t_sector==0 [pweight=extri], cluster(livdep)
outreg2 using "table_A2_G3B.xls", bdec(4) se ctitle("DD Control sector") bracket append				
outreg2 using "table_A2_G3B_s.xls", bdec(4) se ctitle("DD Control sector") keep(alsacemo*) bracket append		

regress us_hours t_sector##i.year t_sector##i.livdep t_sector##i.cse_n  ddipl1 ///
		ddipl3 ddipl4 ddipl5 ddipl6 ddipl9 ///
		male hhldsize ag5dum*  ///
		alsacemo03 alsacemo0102 alsacemo9900 ///		
		t_sector##alsacemo03 t_sector##alsacemo0102 t_sector##alsacemo9900  if f3==1 [pweight=extri], cluster(livdep)
outreg2 using "table_A2_G3B.xls", bdec(4) se ctitle("DDD sector") bracket append		
outreg2 using "table_A2_G3B_s.xls", bdec(4) se ctitle("DDD sector") keep(alsacemo* t_sector##alsacemo*) bracket append		

		
**************************************************************************************
* Table G4. Descriptive statistics on border workers
**************************************************************************************
tabstat borderwo if f3==1 & country1==1, by (livdep) st(me n)
tabstat borderwo if f3==1 & country1==1, by (alsacemo) st(me n)		
tab peta if f3==1 & alsacemo==1 & peta!="10"


**************************************************************************************
* Figure G1. Nomber of hours through time in Alsace-Moselle and France depending on country of work
**************************************************************************************
tabstat us_hours if f3==1 & t_occ==1 & alsacemo==0, by (year) st(me sem sd n)  /*Rest of France */
tabstat us_hours if f3==1 & t_occ==1 & alsacemo==1, by (year) st(me sem sd n) /*Alsace Moselle */
tabstat us_hours if f3==1 & t_occ==1 & alsacemo==1 & borderwo==0, by (year) st(me sem sd n) col(stat) /*Alsace Moselle non border*/
tabstat us_hours if f3==1 & t_occ==1 & alsacemo==1 & borderwo==1, by (year) st(me sem sd n) col(stat) /*Alsace Moselle border*/

/*Graphs are done on excel*/
		
**************************************************************************************
* Table G5. PANEL A. REPLICATION OF TABLE 1. Excluding borderworkers
**************************************************************************************
regress us_hours i.year i.livdep i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* ///
		alsacemo03 alsacemo0102 alsacemo9900 if f3b==1 & t_occ==1 [pweight=extri], cluster(livdep)
outreg2 using "table_1_G5.xls", bdec(4) se ctitle("DD Target occ") bracket replace
outreg2 using "table_1_G5_s.xls", bdec(4) se ctitle("DD Target occ") keep(alsacemo*) bracket replace

regress us_hours i.year i.livdep i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* ///
		alsacemo03 alsacemo0102 alsacemo9900 if f3b==1 & t_occ==0 [pweight=extri], cluster(livdep)
outreg2 using "table_1_G5.xls", bdec(4) se ctitle("DD Control occ") bracket append		
outreg2 using "table_1_G5_s.xls", bdec(4) se ctitle("DD Control occ") keep(alsacemo*) bracket append		
		
regress us_hours t_occ##i.year t_occ##i.livdep t_occ##i.cse_n ddipl1 ///
		ddipl3 ddipl4 ddipl5 ddipl6 ddipl9 ///
		male hhldsize ag5dum*  ///
		alsacemo03 alsacemo0102 alsacemo9900 ///
		t_occ##alsacemo03 t_occ##alsacemo0102 t_occ##alsacemo9900  if f3b==1 [pweight=extri], cluster(livdep)
outreg2 using "table_1_G5.xls", bdec(4) se ctitle("DDD occ") bracket append		
outreg2 using "table_1_G5_s.xls", bdec(4) se ctitle("DDD occ") keep(alsacemo* t_occ##alsacemo*) bracket append		

regress us_hours i.year i.livdep i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum*  ///
		alsacemo03 alsacemo0102 alsacemo9900 if f3b==1 & t_ind==1 [pweight=extri], cluster(livdep)
outreg2 using "table_1_G5.xls", bdec(4) se ctitle("DD Target ind") bracket append		
outreg2 using "table_1_G5_s.xls", bdec(4) se ctitle("DD Target ind") keep(alsacemo*) bracket append		

regress us_hours i.year i.livdep i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* ///
		alsacemo03 alsacemo0102 alsacemo9900 if f3b==1 & t_ind==0 [pweight=extri], cluster(livdep)
outreg2 using "table_1_G5.xls", bdec(4) se ctitle("DD Control ind") bracket append				
outreg2 using "table_1_G5_s.xls", bdec(4) se ctitle("DD Control ind") keep(alsacemo*) bracket append		
		
regress us_hours t_ind##i.year t_ind##i.livdep t_ind##i.cse_n  ddipl1 ///
		ddipl3 ddipl4 ddipl5 ddipl6 ddipl9 ///
		male hhldsize ag5dum*  ///
		alsacemo03 alsacemo0102 alsacemo9900 ///		
		t_ind##alsacemo03 t_ind##alsacemo0102 t_ind##alsacemo9900  if f3b==1 [pweight=extri], cluster(livdep)
outreg2 using "table_1_G5.xls", bdec(4) se ctitle("DDD ind") bracket append		
outreg2 using "table_1_G5_s.xls", bdec(4) se ctitle("DDD ind") keep(alsacemo* t_ind##alsacemo*) bracket append		

regress us_hours i.year i.livdep i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum*  ///
		alsacemo03 alsacemo0102 alsacemo9900 bordergdp if f3b==1 & t_ind==1 [pweight=extri], cluster(livdep)
outreg2 using "table_1_G5.xls", bdec(4) se ctitle("DD ind + bordergdp") bracket append		
outreg2 using "table_1_G5_s.xls", bdec(4) se ctitle("DD ind + bordergdp") keep(alsacemo* t_ind##alsacemo* bordergdp) bracket append		


**************************************************************************************
* Table G5. PANEL B. REPLICATION OF TABLE A2. Excluding borderworkers
**************************************************************************************
	
regress us_hours i.year i.livdep i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* ///
		alsacemo03 alsacemo0102 alsacemo9900 if f3b==1 & t_firm==1 [pweight=extri], cluster(livdep)
outreg2 using "table_A2_G5.xls", bdec(4) se ctitle("DD Target firm") bracket replace
outreg2 using "table_A2_G5_s.xls", bdec(4) se ctitle("DD Target firm") keep(alsacemo*) bracket replace

regress us_hours i.year i.livdep i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* ///
		alsacemo03 alsacemo0102 alsacemo9900 if f3b==1 & t_firm==0 [pweight=extri], cluster(livdep)
outreg2 using "table_A2_G5.xls", bdec(4) se ctitle("DD Control firm") bracket append		
outreg2 using "table_A2_G5_s.xls", bdec(4) se ctitle("DD Control firm") keep(alsacemo*) bracket append		
		
regress us_hours t_firm##i.year t_firm##i.livdep t_firm##i.cse_n  ddipl1 ///
		ddipl3 ddipl4 ddipl5 ddipl6 ddipl9 ///
		male hhldsize ag5dum*  ///
		alsacemo03 alsacemo0102 alsacemo9900 ///		
		t_firm##alsacemo03 t_firm##alsacemo0102 t_firm##alsacemo9900  if f3b==1 [pweight=extri], cluster(livdep)		
outreg2 using "table_A2_G5.xls", bdec(4) se ctitle("DDD firm") bracket append		
outreg2 using "table_A2_G5_s.xls", bdec(4) se ctitle("DDD firm") keep(alsacemo* t_firm##alsacemo*) bracket append		
		
regress us_hours i.year i.livdep i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* ///
		alsacemo03 alsacemo0102 alsacemo9900 if f3b==1 & t_sector==1 [pweight=extri], cluster(livdep)
outreg2 using "table_A2_G5.xls", bdec(4) se ctitle("DD Target sector") bracket append		
outreg2 using "table_A2_G5_s.xls", bdec(4) se ctitle("DD Target sector") keep(alsacemo*) bracket append		

regress us_hours i.year i.livdep i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* ///
		alsacemo03 alsacemo0102 alsacemo9900 if f3b==1 & t_sector==0 [pweight=extri], cluster(livdep)
outreg2 using "table_A2_G5.xls", bdec(4) se ctitle("DD Control sector") bracket append				
outreg2 using "table_A2_G5_s.xls", bdec(4) se ctitle("DD Control sector") keep(alsacemo*) bracket append		

regress us_hours t_sector##i.year t_sector##i.livdep t_sector##i.cse_n  ddipl1 ///
		ddipl3 ddipl4 ddipl5 ddipl6 ddipl9 ///
		male hhldsize ag5dum*  ///
		alsacemo03 alsacemo0102 alsacemo9900 ///		
		t_sector##alsacemo03 t_sector##alsacemo0102 t_sector##alsacemo9900  if f3b==1 [pweight=extri], cluster(livdep)
outreg2 using "table_A2_G5.xls", bdec(4) se ctitle("DDD sector") bracket append		
outreg2 using "table_A2_G5_s.xls", bdec(4) se ctitle("DDD sector") keep(alsacemo* t_sector##alsacemo*) bracket append		

regress us_hours t_firm##i.year t_firm##i.livdep t_firm##i.cse_n  ddipl1 ///
		ddipl3 ddipl4 ddipl5 ddipl6 ddipl9 ///
		male hhldsize ag5dum*  ///
		alsacemo03 alsacemo0102 alsacemo9900 ///		
		t_firm##alsacemo03 t_firm##alsacemo0102 t_firm##alsacemo9900  ///
		if f3b==1 & t_occ==1 [pweight=extri], cluster(livdep)
outreg2 using "table_1_G5.xls", bdec(4) se ctitle("DDD t_firm Target occ") bracket append		
outreg2 using "table_1_G5_s.xls", bdec(4) se ctitle("DDD t_firm Target occ") keep(alsacemo* t_firm##alsacemo*) bracket append		


**************************************************************************************
* Table GA1. Descriptive statistics
**************************************************************************************
tabstat us_hours if f1==1, by(alsacemo) st(me sd co) col(stat)
tabstat us_hours lw_hours if f3==1 & year==2003 & (datdeb=="20031222" | datdeb=="20030414"), by(alsacemo) st(me sd co) col(stat)
tabstat us_hours lw_hours us_hours lw_hours t_firm t_sector t_occ t_ind ///
							age1524-age60pl male hhldsize ddipl1-ddipl7 ddipl9 ///
							hwage lhwage if f3==1 , by(alsacemo) st(me sd co) col(stat)
tabstat employed unemploy, by(alsacemo) st(me sd co) col(stat)

**************************************************************************************
* Table GA2. Descriptive statistics on firm variable
**************************************************************************************
tabstat t_firm99 t_firm0 t_firmb t_firm if f3==1, by(year)
tabstat t_firm99 if f3==1, by(year) st(co)



**************************************************************************************
* Figures GA1 to GA3. Number of hours through time in Alsace-Moselle and France depending on country of work
**************************************************************************************
/*tables for selecting the top 3 biggest and lowest regional evolutions between period 9698 and period 200102*/
tabstat us_hours if f3==1, by (livregperiod) st(me sem sd n)  /*Region*Period full time worker*/
tabstat us_hours if f3==1 & t_occ==1, by (livregperiod) st(me sem sd n)  /*Region*Period full time worker & target occ*/
tabstat us_hours if f3==1 & t_occ==1 & borderwo==1, by (livregperiod) st(me sem sd n)  /*Region*Period full time worker & target occ no border workers*/

/*All yearly evolution*/
tabstat us_hours if f3==1, by (livregyear) st(me sem sd n)  /*Region*year full time worker*/
tabstat us_hours if f3==1 & t_occ==1, by (livregyear) st(me sem sd n)  /*Region*year full time worker & target occ*/
tabstat us_hours if f3==1 & t_occ==1 & borderwo==1, by (livregyear) st(me sem sd n)  /*Region*year full time worker & target occ no border workers*/

/*Graphs are done on excel*/

**************************************************************************************
* OTHER CHECKS
**************************************************************************************

**************************************************************************************
* Check for Table 2 Replication
**************************************************************************************
xi: probit employed i.year i.livdep i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* ///
		alsacemo9900 alsacemo0102 /*alsacemo03*/ if f4==1 & t_occ==1 [pweight=extri], cluster(livdep)
outreg2 using "table_2.xls", bdec(4) se ctitle("DD Target occ") bracket replace
outreg2 using "table_2_s.xls", bdec(4) se ctitle("DD Target occ") keep(alsacemo*) bracket replace

xi: probit employed i.year i.livdep i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* ///
		alsacemo9900 alsacemo0102 /*alsacemo03*/ if f4==1 & t_occ==0 [pweight=extri], cluster(livdep)
outreg2 using "table_2.xls", bdec(4) se ctitle("DD Control occ") bracket append		
outreg2 using "table_2_s.xls", bdec(4) se ctitle("DD Control occ") keep(alsacemo*) bracket append		

		
xi: probit employed i.t_occyear i.t_occlivdep i.t_occcse_n  ddipl1 ///
		ddipl3 ddipl4 ddipl5 ddipl6 ddipl9 ///
		male hhldsize ag5dum*  ///
		alsacemo03 alsacemo0102 alsacemo9900 ///		
		t_occalsacemo03 t_occalsacemo0102 /*t_occalsacemo03*/ if f4==1 [pweight=extri], cluster(livdep)
outreg2 using "table_2.xls", bdec(4) se ctitle("DDD occ") bracket append		
outreg2 using "table_2_s.xls", bdec(4) se ctitle("DDD occ") keep(alsacemo* t_occalsacemo*) bracket append		
		
xi: probit employed i.t_occyear i.t_occlivdep i.t_occcse_n  ddipl1 ///
		ddipl3 ddipl4 ddipl5 ddipl6 ddipl9 ///
		male hhldsize ag5dum*  ///
		alsacemo03 alsacemo0102 alsacemo9900 ///
		t_occalsacemo03 t_occalsacemo0102 /*t_occalsacemo03*/ if f4==1 & skilled==1 [pweight=extri], cluster(livdep)
outreg2 using "table_2.xls", bdec(4) se ctitle("DDD occ skilled") bracket append		
outreg2 using "table_2_s.xls", bdec(4) se ctitle("DDD occ skilled") keep(alsacemo* t_occalsacemo*) bracket append		

xi: probit employed i.t_occyear i.t_occlivdep i.t_occcse_n  ddipl1 ///
		ddipl3 ddipl4 ddipl5 ddipl6 ddipl9 ///
		male hhldsize ag5dum*  ///
		alsacemo03 alsacemo0102 alsacemo9900 ///		
		t_occalsacemo03 t_occalsacemo0102 /*t_occalsacemo03*/ if f4==1 & skilled==1 [pweight=extri], cluster(livdep)
outreg2 using "table_2.xls", bdec(4) se ctitle("DDD occ unskilled") bracket append		
outreg2 using "table_2_s.xls", bdec(4) se ctitle("DDD occ unskilled") keep(alsacemo* t_occalsacemo*) bracket append		
		
xi: probit employed i.year i.livdep i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* ///
		alsacemo9900 alsacemo0102 bordergdp/*alsacemo03*/ if f4==1 & t_occ==1 [pweight=extri], cluster(livdep)
outreg2 using "table_2.xls", bdec(4) se ctitle("DD Target occ + bordergdp") bracket append
outreg2 using "table_2_s.xls", bdec(4) se ctitle("DD Target occ + bordergdp") keep(alsacemo* bordergdp) bracket append

		
**************************************************************************************
* Table 3
**************************************************************************************
set matsize 1000

xi: probit unemploy i.year i.livdep i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* ///
		alsacemo9900 alsacemo0102 /*alsacemo03*/ if f5==1 & t_occ==1 [pweight=extri], cluster(livdep)
outreg2 using "table_3.xls", bdec(4) se ctitle("DD target occ") bracket replace		
outreg2 using "table_3_s.xls", bdec(4) se ctitle("DD target occ") keep(alsacemo* t_occalsacemo*) bracket replace		

xi: probit unemploy i.year i.livdep i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* ///
		alsacemo9900 alsacemo0102 /*alsacemo03*/ if f5==1 & t_occ==0 [pweight=extri], cluster(livdep)
outreg2 using "table_3.xls", bdec(4) se ctitle("DD control occ") bracket append		
outreg2 using "table_3_s.xls", bdec(4) se ctitle("DD control occ") keep(alsacemo* t_occalsacemo*) bracket append		
		
xi: probit unemploy i.t_occyear i.t_occlivdep i.t_occcse_n  ddipl1 ///
		ddipl3 ddipl4 ddipl5 ddipl6 ddipl9 ///
		male hhldsize ag5dum*  ///
		alsacemo03 alsacemo0102 alsacemo9900 ///		
		t_occalsacemo03 t_occalsacemo0102 /*t_occalsacemo03*/ if f5==1 [pweight=extri], cluster(livdep)
outreg2 using "table_3.xls", bdec(4) se ctitle("DDD occ") bracket append		
outreg2 using "table_3_s.xls", bdec(4) se ctitle("DDD occ") keep(alsacemo* t_occalsacemo*) bracket append		
		
xi: probit unemploy i.t_occyear i.t_occlivdep i.t_occcse_n  ddipl1 ///
		ddipl3 ddipl4 ddipl5 ddipl6 ddipl9 ///
		male hhldsize ag5dum*  ///
		alsacemo03 alsacemo0102 alsacemo9900 ///
		t_occalsacemo03 t_occalsacemo0102 /*t_occalsacemo03*/ if f5==1 & skilled==1 [pweight=extri], cluster(livdep)
outreg2 using "table_3.xls", bdec(4) se ctitle("DDD occ unskilled") bracket append		
outreg2 using "table_3_s.xls", bdec(4) se ctitle("DDD occ unskilled") keep(alsacemo* t_occalsacemo*) bracket append		

xi: probit unemploy i.t_occyear i.t_occlivdep i.t_occcse_n  ddipl1 ///
		ddipl3 ddipl4 ddipl5 ddipl6 ddipl9 ///
		male hhldsize ag5dum*  ///
		alsacemo03 alsacemo0102 alsacemo9900 ///		
		t_occalsacemo03 t_occalsacemo0102 /*t_occalsacemo03*/ if f5==1 & skilled==0 [pweight=extri], cluster(livdep)
outreg2 using "table_3.xls", bdec(4) se ctitle("DDD occ unskilled") bracket append		
outreg2 using "table_3_s.xls", bdec(4) se ctitle("DDD occ unskilled") keep(alsacemo* t_occalsacemo*) bracket append		


xi: probit unemploy i.year i.livdep i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* ///
		alsacemo9900 alsacemo0102 /*alsacemo03*/ bordergdp if f5==1 & t_occ==1 [pweight=extri], cluster(livdep)
outreg2 using "table_3.xls", bdec(4) se ctitle("DD target occ + bordergdp") bracket replace		
outreg2 using "table_3_s.xls", bdec(4) se ctitle("DD target occ + bordergdp") keep(alsacemo* t_occalsacemo* bordergdp) bracket replace		

**************************************************************************************
* Check a variant on table 2 DD on targeted occupation and unskilled
**************************************************************************************
xi: probit employed i.year i.livdep i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* ///
		alsacemo9900 alsacemo0102 /*alsacemo03*/ if f4==1 & t_occ==1 & skilled==0 [pweight=extri], cluster(livdep)

