**************************************************************;
* French Labour Force Survey (i.e. Enqute Emploi),         *; 
* and Supplementary survey on working time 1995 and 2001 can *;
* be obtained from Rseau Quetelet http://quetelet.casd.eu/  *;
* I introduced a year variable for each separate file.       *;
* The data for the full years and the necessary variable were*;
* then transformed to a SAS export file for other softwares. *;
**************************************************************;

options ps=max ls=max nodate nocenter nonumber;

libname jole "D:\Olivier\Documents\Universite\data\Emploi\Jole_2009_Data\";

/*
libname jole "D:\Olivier\Documents\Universite\data\Emploi\Jole_2009_Data\";
*/

data m; set jole.dur9501_raw;

if year= 2003 then dea_2=annee; 
else dea_2=(80<dea<100)*(DEA+1900)+(DEA>100)*DEA; 


*Individuals; 
if year<2003 then id=AIRE!!IMLOC!!noi;
else id=IDENT!!NOI;


*Usual working hours;
if 1990<=year<2003 and HH NE "SP" then us_hours=HH*1;
else if year=2003 then us_hours=HHC*1;

*Last week working hours;
if year=2003 then lw_hours=EMPNBH*1;
else lw_hours=HT*1;

*Hourly wage;
if year=2003 then salred=salred*6.55957;
if salred>0 then lsalred=log(SALRED);
if us_hours>0 and salred>0 then hwage=SALRED/(4.34*min(us_hours,48));
if hwage>0 then lhwage=log(hwage);

*Full time; 
fulltim=(DUHAB in ("4","5","6","7")); *Corrected error;

*Gender;
female=(SEXE="2" or S="2");
male=1-female;

*Civil servant;
if annee>="2003" then public=(CHPUB in ("1","2","3"));
else if year<2003 then public=(CHPUB in ("2"));

*Wage earner;
if annee>="2003" then wageearn=(STAT2 in ("2"));
else if year<2003 then wageearn=(ST in ("2"));

*Definition of living department (department fixed effect);
livdep=DEP;
if livdep in ("2A","2B") then livdep="20";

*Definition of working department (livdepartment fixed effect);
if year<2003 and DEPETA NE "" then workdep=DEPETA ;
else if year=2003 then workdep=DEPARC;
if workdep="" then workdep=DEP;
if workdep in ("2A","2B") then workdep="20";

*Alsace Moselle; 
alsacemo=(livdep in ("57","67","68") ); 
alsacemo_alt=(workdep  in ("57","67","68")); 

*Border workers;
borderwo=1-(peta in ("10",""));

*Bordering country; 
* Here I follow exactly the program for the JOLE 2009 article; 
* Other decision could be done for some departments like Moselle (matching with Luxembourg); 
* Or Haut Rhing (matching with Switzerland) and similarly Aisne (02) could be included in the ; 
* List and matched with Belgium; 
length country $12.;
if livdep=59 or livdep=08 or livdep=55 then country="Belgium"; 
else if livdep=54 then country="Luxembourg";
else if livdep=57 or livdep=67 or livdep=68 then  country="Germany";
else if livdep=90 or livdep=25 or livdep=39 or livdep=1 or livdep=74 then  country="Switzerland";
else if livdep=73 or livdep=74 or livdep=4 or livdep=5 or livdep=6 then  country="Italy";
else if livdep=66 or livdep=9 or livdep=31 or livdep=65 or livdep=64 then  country="Spain";
else country="No border";

country1=1-(country="No border");
country2=(country in ("Belgium","Luxembourg","Germany","Switzerland"));

countryb=country;
if livdep=2 then countryb="Belgium";
countryb1=1-(countryb="No border");
countryb2=(countryb in ("Belgium","Luxembourg","Germany","Switzerland"));


*Bordering GDP growth; 
* Data extracted on 24 Sep 2016 10:06 UTC (GMT) from OECD.Stat;
* http://stats.oecd.org/index.aspx?DatasetCode=EO; 
if country="No border" then bordergdp=0;
else if country="Belgium" and year=1996 then bordergdp=1.58960805579247;
else if country="Belgium" and year=1997 then bordergdp=3.7098969741779;
else if country="Belgium" and year=1998 then bordergdp=1.97648077819975;
else if country="Belgium" and year=1999 then bordergdp=3.56273663647085;
else if country="Belgium" and year=2000 then bordergdp=3.64016036893688;
else if country="Belgium" and year=2001 then bordergdp=0.805943529168277;
else if country="Belgium" and year=2002 then bordergdp=1.77955176068139;
else if country="Belgium" and year=2003 then bordergdp=0.774248667313357;
else if country="France" and year=1996 then bordergdp=1.38800402844923;
else if country="France" and year=1997 then bordergdp=2.33733340443809;
else if country="France" and year=1998 then bordergdp=3.55620125228618;
else if country="France" and year=1999 then bordergdp=3.40709914884665;
else if country="France" and year=2000 then bordergdp=3.87516225904453;
else if country="France" and year=2001 then bordergdp=1.95444942459258;
else if country="France" and year=2002 then bordergdp=1.1184568915501;
else if country="France" and year=2003 then bordergdp=0.819531669596682;
else if country="Germany" and year=1996 then bordergdp=0.853803107702814;
else if country="Germany" and year=1997 then bordergdp=1.90478756470841;
else if country="Germany" and year=1998 then bordergdp=1.7755820082395;
else if country="Germany" and year=1999 then bordergdp=1.84519905837833;
else if country="Germany" and year=2000 then bordergdp=3.19740195821453;
else if country="Germany" and year=2001 then bordergdp=1.83767366339264;
else if country="Germany" and year=2002 then bordergdp=0.018796971665527;
else if country="Germany" and year=2003 then bordergdp=-0.730261487285155;
else if country="Luxembourg" and year=1996 then bordergdp=1.52021815057823;
else if country="Luxembourg" and year=1997 then bordergdp=5.95023422423793;
else if country="Luxembourg" and year=1998 then bordergdp=6.48430414707796;
else if country="Luxembourg" and year=1999 then bordergdp=8.42348341729952;
else if country="Luxembourg" and year=2000 then bordergdp=8.4138511615165;
else if country="Luxembourg" and year=2001 then bordergdp=2.14738895086324;
else if country="Luxembourg" and year=2002 then bordergdp=3.62592944338009;
else if country="Luxembourg" and year=2003 then bordergdp=1.41294747363995;
else if country="Spain" and year=1996 then bordergdp=2.67477982295753;
else if country="Spain" and year=1997 then bordergdp=3.68947185154924;
else if country="Spain" and year=1998 then bordergdp=4.30597844697085;
else if country="Spain" and year=1999 then bordergdp=4.48477443037206;
else if country="Spain" and year=2000 then bordergdp=5.28922090746535;
else if country="Spain" and year=2001 then bordergdp=4.00106922543372;
else if country="Spain" and year=2002 then bordergdp=2.87976212105771;
else if country="Spain" and year=2003 then bordergdp=3.18757147564503;
else if country="Switzerland" and year=1996 then bordergdp=0.553143472905909;
else if country="Switzerland" and year=1997 then bordergdp=2.28249395074228;
else if country="Switzerland" and year=1998 then bordergdp=2.86759553716691;
else if country="Switzerland" and year=1999 then bordergdp=1.59413007109722;
else if country="Switzerland" and year=2000 then bordergdp=4.1730931201534;
else if country="Switzerland" and year=2001 then bordergdp=1.45704410800672;
else if country="Switzerland" and year=2002 then bordergdp=0.147402714479676;
else if country="Switzerland" and year=2003 then bordergdp=0.080114046598927;
else if country="Italy" and year=1996 then bordergdp=1.00012290887587;
else if country="Italy" and year=1997 then bordergdp=1.96767328011084;
else if country="Italy" and year=1998 then bordergdp=1.45619718946013;
else if country="Italy" and year=1999 then bordergdp=1.5085997667673;
else if country="Italy" and year=2000 then bordergdp=3.96835161235477;
else if country="Italy" and year=2001 then bordergdp=1.58146107576628;
else if country="Italy" and year=2002 then bordergdp=0.24728101400427;
else if country="Italy" and year=2003 then bordergdp=0.238103105481728;


*Redefinition of living region => Moselle in Alsace;
if year=2003 then livreg= reg; 
else livreg=rg;
if livdep="57" then livreg="42";
if livreg in ("93","94") then livreg="92";



* Placebo Region;
placebo=(livreg="72");

*Size of firm;

if efen98*1>=0 then efenn=EFEN98*1;
else efenn=efen;
IF EFENN=999999 then efenn=.;
efen99=(EFENN=.);
efen20=(efenn>19);
if efen99=0 then efen20W=(efenn>19);

tn20=(TN in ("5","6","7","8","9"));
tn99=(TN="");
tn99b=(TN in ("","0"));
if TN NE "" then tn20W=tn20;
if TN99b NE 1 then tn20Wb=tn20;
tn20e=tn20+tn99;
tn20be=tn20+tn99b;

nbsalb20=(NBSALB in ("5","6","7","8","9"));
nbsalb99=(NBSALB="" or nbsalb="99");
if nbsalb not in ("","99") then nbsalb2W=nbsalb20;

*Targeted diploma;
t_ddipl=("4"<DDIPL<"8");


*Targeted occupation;
t_occ_o=("31"<CSE<"70");
t_occ=(t_occ_o=1 and CSE NOT in ("34","42","44","56"));
t_occ_a=(t_occ_o=1 and CSE NOT in ("34","42","44","56","62","63","68"));

*Targeted firm; 
if public=1 then t_firm =1; 
else if year=2003 and efenn>19 and efenn ne . then t_firm=1;
else if year=2003 and efenn<=19 and efenn ne . then t_firm=0;
else if year=2003 and NBSALB in ("5","6","7","8","9") then t_firm=1;
else if year=2003 and NBSALB in ("0","1","2","3","4") then t_firm=0;
else if year<2003 and TN in ("5","6","7","8","9") then t_firm=1;
else if 1997<year<2003 and TN in ("0","1","2","3","4") then t_firm=0;
else if year<1998 and TN in ("1","2","3","4") then t_firm=0;
else if wageearn=0 then t_firm=0;

t_firm_o=( ( year=2003 and (efen20=1 or (nbsalb20=1 & efen99=1)) ) or tn20=1 or public=1);;
t_firm_e=(efenn>19 | efenn=.);*Error as in the paper;

t_firm5=t_firm_o; 
if t_firm=0 and efen99 = 1 and tn99 = 1 and nbsalb99 = 1 and public=0 then t_firm5=.;

if public=1 then t_firm6 =1; 
else if year=2003 and efenn>19 and efenn ne . then t_firm6=1;
else if year=2003 and efenn<=19 and efenn ne . then t_firm6=0;
else if year=2003 and NBSALB in ("5","6","7","8","9") then t_firm6=1;
else if year=2003 and NBSALB in ("0","1","2","3","4") then t_firm6=0;
else if year<2003 and TN in ("5","6","7","8","9") then t_firm6=1;
else if year<2003 and TN in ("0","1","2","3","4") then t_firm6=0;
else if wageearn=0 then t_firm6=0;

*Targeted sector;
if year=2003 then sector=NAFG36U; 
else sector=NAFG36; 
t_sector=(sector in ("F5","J3","P1","H0"));

*Targeted individuals;
t_ind=(t_occ+t_firm+t_sector>=3);
if t_firm=. then t_ind=.; 

*Age; 
agen=max(AGE,AG)*1;
age1524=(15<=agen<=24);
age2539=(25<=agen<=39);
age4049=(40<=agen<=49);
age5059=(50<=agen<=59);
age60pl=(60<=agen);

*Household size; 
if year<2003 then hhldsize=NP; 
else hhldsize=NBINDE;
hhldsize=min(hhldsize,5);

*Diploma; 
ddipl1=(DDIPL="1");
ddipl3=(DDIPL="3");
ddipl4=(DDIPL="4");
ddipl5=(DDIPL="5");
ddipl6=(DDIPL="6");
ddipl7=(DDIPL="7");
ddipl9=(DDIPL="");

*Period;
per9900=(year in (1999,2000));
per0102=(year in (2001,2002));
per03=(year in (2003));
per0003=(year >1999);
per0002=(year in (2000,2001,2002));
per9902=(year in (1999,2000,2001,2002));
per99=(year in (1999));
per0001=(year in (2000,2001));
per0203=(year in (2002,2003));

alsacemoper9900=alsacemo*(year in (1999,2000));
alsacemoper0102=alsacemo*(year in (2001,2002));
alsacemoper03=alsacemo*(year in (2003));

*Employment;
act3=ACT;
if year=2003 then act3=ACTEU;

if year=2003 then act7=ACTEU6;

employed=(act3="1");
if act3 in ("1","2") then unemploy=(act3="2");

employe2=2-employed;
unemplo2=2-unemploy;

*Weighting;
*Not used finally, but does not change the result;
if year=1996 then myweight=EXTRI/310.4347687;
else if year=1997 then myweight=EXTRI/315.6802023;
else if year=1998 then myweight=EXTRI/316.7074069 ;
else if year=1999 then myweight=EXTRI/317.9776784;
else if year=2000 then myweight=EXTRI/319.5822449;
else if year=2001 then myweight=EXTRI/325.2955491;
else if year=2002 then myweight=EXTRI/331.2362126;
else if year=2003 then myweight=EXTRI/683.6374883;

myweight2=100*myweight;

*Skilled; 
skilled=(ddipl in ("1","3"))*1;
skilled2=(ddipl in ("1","3","4"))*1;

CS_f20=(CSE*1 in (54,43,46,37,64,52,47,38,65,48,62,67));

*Field; 
all=1;

f1=(act7="1" | act7="3" | act7="4");
f2=(f1=1 and fulltim=1);
f3=(f2=1 & CSE NE "" &  us_hours NE .  & hhldsize NE . & livdep NE "" & agen NE . and extri NE . and extri NE 0);
f4=(CSE NE ""  & hhldsize NE . & livdep NE "" & agen NE . and year<2003 and extri NE . and extri NE 0);
f5=(f4=1 & ACT3 in ("1","2") );

f3b=(f2=1 & CSE NE "" &  us_hours NE .  & hhldsize NE . & livdep NE "" & agen NE . & borderwo=0 and extri NE . and extri NE 0);
f4b=(CSE NE ""  & hhldsize NE . & livdep NE "" & agen NE . and extri NE . and extri NE 0);
f5b=(f4b=1 & ACT3 in ("1","2"));


*Variables for DUR95 & DUR01;

if year=1995 then us_hours2=DURHEBDO/60;
else us_hours2=DTHPR;

if dyear =2001 then do; 
	HREDUC1=(hREDUC=1);
	HACCOR1=(HACCOR=1);
	gtravp123=(gtravp in ("1","2","3"));

	if haccor="1" then do; 
		rtt1=(hredui1=1 |hredui2=1 | hredui3=1 | hredui4=1);
		rtt2=(hredui1=2 |hredui2=2 | hredui3=2 | hredui4=2);
		rtt3=(hredui1=3 |hredui2=3 | hredui3=3 | hredui4=3);
		rtt4=(hredui1=4 |hredui2=4 | hredui3=4 | hredui4=4);
		rtt5=(hredui1=5 |hredui2=5 | hredui3=5 | hredui4=5);
		rtt6=(hredui1=6 |hredui2=6 | hredui3=6 | hredui4=6);
		rtt7=(hredui1=7 |hredui2=7 | hredui3=7 | hredui4=7);
		rtt8=(hredui1=8 |hredui2=8 | hredui3=8 | hredui4=8);
		rtt9=(hredui1="" & hredui2="" & hredui3="" & hredui4="");

		freertt1=(hlrtt1=1 |hlrtt2=1 | hlrtt3=1 | hlrtt4=1);
		freertt2=(hlrtt1=2 |hlrtt2=2 | hlrtt3=2 | hlrtt4=2);
		freertt3=(hlrtt1=3 |hlrtt2=3 | hlrtt3=3 | hlrtt4=3);
		freertt4=(hlrtt1=4 |hlrtt2=4 | hlrtt3=4 | hlrtt4=4);
		freertt5=(hlrtt1=5 |hlrtt2=5 | hlrtt3=5 | hlrtt4=5);
		freertt6=(hlrtt1=6 |hlrtt2=6 | hlrtt3=6 | hlrtt4=6);
		freertt7=(hlrtt1=7 |hlrtt2=7 | hlrtt3=7 | hlrtt4=7);
		freertt9=(hlrtt1="" & hlrtt2="" & hlrtt3="" & hlrtt4="");

		if h3RED<"99" then h3redn=h3red*1;
		h3REDNB=h3redn;
		if h3REDNB>22 then h3rednB=23;

		h3REDNC=h3redn;
		h3REDND=h3rednB;
		if h3RED="" then h3REDNC=0; 
		if h3RED="" then h3REDND=0; 

		if h3RED NE "" then h3REDN13=(0<h3redn<=13);
		if h3RED NE "" then h3REDN20=(13<h3redn<21);
		if h3RED NE "" then h3REDN21=(h3redn>=21);

		h3REDNB13=(0<h3redn<=13);
		h3REDNB20=(13<h3redn<21);
		h3REDNB21=(h3redn>=21);

		if HREFFE NE ""  then hreffe1=(hreffe=1);
		hreffeb1=(hreffe1=1 or hreffe1=. and (rtt2=1 or rtt3=1));

		if hcrtt NE "" then hcrtt1=(hcrtt=1);
		if hcrtt NE "" then hcrtt2=(hcrtt=2);
		if hcrtt NE "" then hcrtt3=(hcrtt=3);
	end;
end;
run;

proc tabulate data=m format=8.4 order=formatted; 
title "Table G6 Descriptive statistics all active workers";
class alsacemo dyear;
var  us_hours us_hours2 HREDUC1 HACCOR1 ;
table (us_hours*dyear us_hours2*DYEAR HREDUC1 HACCOR1 ),ALSACEMO*(MEAN STD N  );
where F3b=1;
format alsacemo alsacemo.;
quit;

proc tabulate data=m format=8.4 order=formatted; 
title "Table G6 Descriptive statistics for workers benefiting form Reduction working time";
class alsacemo ;
var us_hours us_hours2 rtt1-rtt3 H3REDN H3REDN13 H3REDN20 H3REDN21 rtt4--rtt8 hreffe1 hcrtt3 hcrtt3 freertt1--freertt9 gtravp123 ;
table (us_hours us_hours2 rtt1-rtt3 H3REDN H3REDN13 H3REDN20 H3REDN21 rtt4--rtt8 hreffe1 hcrtt3 freertt1--freertt9 gtravp123),ALSACEMO*(MEAN STD N);
where F3b=1 and HACCOR="1" ;
format alsacemo alsacemo.;
run;

proc surveyreg data=m; title "Table G6 D us_hours 1995"; cluster  livdep ;class year CSE ;model us_hours=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /solution ; weight extri; where F3b=1 and dyear=1995; quit;
proc surveyreg data=m; title "Table G6 D us_hours 2001"; cluster  livdep ;class year CSE ;model us_hours=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /solution ; weight extri; where F3b=1 and dyear=2001; quit;
proc surveyreg data=m; title "Table G6 D us_hours2 1995"; cluster  livdep ;class year CSE ;model us_hours2=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /solution ; weight extri; where F3b=1 and dyear=1995; quit;
proc surveyreg data=m; title "Table G6 D us_hours2 2001"; cluster  livdep ;class year CSE ;model us_hours2=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /solution ; weight extri; where F3b=1 and dyear=2001; quit;
proc surveyreg data=m; title "Table G6 D HREDUC1 "; cluster  livdep ;class year CSE ;model HREDUC1=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /solution ; weight extri; where F3b=1 ; quit;
proc surveyreg data=m; title "Table G6 D HACCOR1"; cluster  livdep ;class year CSE ;model HACCOR1=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /solution ; weight extri; where F3b=1 ; quit;
proc surveyreg data=m; title "Table G6 D us_hours (Field: HACCOR1)"; cluster  livdep ;class year CSE ;model us_hours=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /solution ; weight extri; where F3b=1 and haccor='1'; quit;
proc surveyreg data=m; title "Table G6 D us_hours2 (Field: HACCOR1)"; cluster  livdep ;class year CSE ;model us_hours2=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /solution ; weight extri; where F3b=1 and haccor='1'; quit;
proc surveyreg data=m; title "Table G6 D rtt1"; cluster  livdep ;class year CSE ;model rtt1=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /solution ; weight extri; where F3b=1 and haccor='1'; quit;
proc surveyreg data=m; title "Table G6 D rtt2"; cluster  livdep ;class year CSE ;model rtt2=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /solution ; weight extri; where F3b=1 and haccor='1'; quit;
proc surveyreg data=m; title "Table G6 D rtt3"; cluster  livdep ;class year CSE ;model rtt3=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /solution ; weight extri; where F3b=1 and haccor='1'; quit;
proc surveyreg data=m; title "Table G6 D h3redn"; cluster  livdep ;class year CSE ;model h3redn=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /solution ; weight extri; where F3b=1 and haccor='1'; quit;
proc surveyreg data=m; title "Table G6 D h3REDN13"; cluster  livdep ;class year CSE ;model h3REDN13=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /solution ; weight extri; where F3b=1 and haccor='1'; quit;
proc surveyreg data=m; title "Table G6 D h3REDN20"; cluster  livdep ;class year CSE ;model h3REDN20=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /solution ; weight extri; where F3b=1 and haccor='1'; quit;
proc surveyreg data=m; title "Table G6 D h3REDN21"; cluster  livdep ;class year CSE ;model h3REDN21=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /solution ; weight extri; where F3b=1 and haccor='1'; quit;
proc surveyreg data=m; title "Table G6 D rtt4"; cluster  livdep ;class year CSE ;model rtt4=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /solution ; weight extri; where F3b=1 and haccor='1'; quit;
proc surveyreg data=m; title "Table G6 D rtt5"; cluster  livdep ;class year CSE ;model rtt5=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /solution ; weight extri; where F3b=1 and haccor='1'; quit;
proc surveyreg data=m; title "Table G6 D rtt6"; cluster  livdep ;class year CSE ;model rtt6=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /solution ; weight extri; where F3b=1 and haccor='1'; quit;
proc surveyreg data=m; title "Table G6 D rtt7"; cluster  livdep ;class year CSE ;model rtt7=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /solution ; weight extri; where F3b=1 and haccor='1'; quit;
proc surveyreg data=m; title "Table G6 D rtt8"; cluster  livdep ;class year CSE ;model rtt8=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /solution ; weight extri; where F3b=1 and haccor='1'; quit;
proc surveyreg data=m; title "Table G6 D hreffe1"; cluster  livdep ;class year CSE ;model hreffe1=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /solution ; weight extri; where F3b=1 and haccor='1'; quit;
proc surveyreg data=m; title "Table G6 D hcrtt3"; cluster  livdep ;class year CSE ;model hcrtt3=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /solution ; weight extri; where F3b=1 and haccor='1'; quit;
proc surveyreg data=m; title "Table G6 D freertt1"; cluster  livdep ;class year CSE ;model freertt1=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /solution ; weight extri; where F3b=1 and haccor='1'; quit;
proc surveyreg data=m; title "Table G6 D freertt2"; cluster  livdep ;class year CSE ;model freertt2=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /solution ; weight extri; where F3b=1 and haccor='1'; quit;
proc surveyreg data=m; title "Table G6 D freertt3"; cluster  livdep ;class year CSE ;model freertt3=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /solution ; weight extri; where F3b=1 and haccor='1'; quit;
proc surveyreg data=m; title "Table G6 D freertt4"; cluster  livdep ;class year CSE ;model freertt4=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /solution ; weight extri; where F3b=1 and haccor='1'; quit;
proc surveyreg data=m; title "Table G6 D freertt5"; cluster  livdep ;class year CSE ;model freertt5=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /solution ; weight extri; where F3b=1 and haccor='1'; quit;
proc surveyreg data=m; title "Table G6 D freertt6"; cluster  livdep ;class year CSE ;model freertt6=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /solution ; weight extri; where F3b=1 and haccor='1'; quit;
proc surveyreg data=m; title "Table G6 D freertt7"; cluster  livdep ;class year CSE ;model freertt7=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /solution ; weight extri; where F3b=1 and haccor='1'; quit;
proc surveyreg data=m; title "Table G6 D freertt9"; cluster  livdep ;class year CSE ;model freertt9=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /solution ; weight extri; where F3b=1 and haccor='1'; quit;
proc surveyreg data=m; title "Table G6 D gtravp123"; cluster  livdep ;class year CSE ;model gtravp123=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /solution ; weight extri; where F3b=1 and haccor='1'; quit;


*DD for table G6; 
proc glm data=m; title "TABLE G6. D us_hours2 in Alsace-Moselle"; *cluster  livdep ;class dyear CSE livdep ;
model us_hours us_hours2=per0102
/solution ; *weight extri; where F3b=1 and alsacemo=1; 
quit;


proc glm data=m; title "TABLE G6. D us_hours2 in France"; *cluster  livdep ;class dyear CSE livdep ;
model us_hours us_hours2=per0102
/solution ; *weight extri; where F3b=1 and alsacemo=0; 
quit;


proc glm data=m; title "TABLE G6. DD us_hours2 "; *cluster  livdep ;class dyear CSE livdep ;
model us_hours us_hours2=alsacemo per0102
alsacemo*per0102 
/solution ; *weight extri; where F3b=1 ; 
quit;

proc surveyreg data=m; title "TABLE G6. DD us_hours "; cluster  livdep ;class dyear CSE livdep ;
model us_hours=dyear livdep CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl 
alsacemo*per0102 
/solution ; weight extri; where F3b=1 ; 
quit;


proc surveyreg data=m; title "TABLE G6. DD us_hours2 "; cluster  livdep ;class dyear CSE livdep ;
model us_hours2=dyear livdep CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl 
alsacemo*per0102 
/solution ; weight extri; where F3b=1 ; 
quit;


*******************************************************************************************************************;
* Table GA3. Replication of Table 1 and GA2, with supplemantary duration of work surveys. Border workers excluded.
*********************************************************************************************************************;
proc surveyreg data=m; title "Table GA3 DD us_hours2 "; cluster  livdep ;class dyear CSE livdep ;
model us_hours2=dyear livdep CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl 
alsacemo*per0102 
/solution ; weight extri; where F3b=1 ; 
quit;


proc surveyreg data=m; title "Table GA3 DD us_hours2 t_occ=1"; cluster  livdep ;class dyear CSE livdep ;
model us_hours2=dyear livdep CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl 
alsacemo*per0102 
/solution ; weight extri; where F3b=1 and t_occ=1; 
quit;


proc surveyreg data=m; title "Table GA3 DD us_hours2 t_occ=0"; cluster  livdep ;class dyear CSE livdep ;
model us_hours2=dyear livdep CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl 
alsacemo*per0102 
/solution ; weight extri; where F3b=1 and t_occ=0; 
quit;


proc surveyreg data=m; title "Table GA3 DDD us_hours2 t_occ"; cluster  livdep ;class dyear CSE livdep ;
model us_hours2=dyear livdep CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl 
t_occ*dyear t_occ*CSE t_occ*livdep 
alsacemo*per0102 
t_occ*alsacemo*per0102 
/solution ; weight extri; where F3b=1 ; 
quit;


proc surveyreg data=m; title "Table GA3 DD us_hours2 t_ind=1"; cluster  livdep ;class dyear CSE livdep ;
model us_hours2=dyear livdep CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl 
alsacemo*per0102 
/solution ; weight extri; where F3b=1 and t_ind=1; 
quit;


proc surveyreg data=m; title "Table GA3 DD us_hours2 t_ind=0"; cluster  livdep ;class dyear CSE livdep ;
model us_hours2=dyear livdep CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl 
alsacemo*per0102 
/solution ; weight extri; where F3b=1 and t_ind=0; 
quit;


proc surveyreg data=m; title "Table GA3 DDD us_hours2 t_ind"; cluster  livdep ;class dyear CSE livdep ;
model us_hours2=dyear livdep CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl 
t_ind*dyear t_ind*CSE t_ind*livdep 
alsacemo*per0102 
t_ind*alsacemo*per0102 
/solution ; weight extri; where F3b=1 ; 
quit;



proc surveyreg data=m; title "Table GA3 DD us_hours2 t_firm=1"; cluster  livdep ;class dyear CSE livdep ;
model us_hours2=dyear livdep CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl 
alsacemo*per0102 
/solution ; weight extri; where F3b=1 and t_firm=1; 
quit;


proc surveyreg data=m; title "Table GA3 DD us_hours2 t_firm=0"; cluster  livdep ;class dyear CSE livdep ;
model us_hours2=dyear livdep CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl 
alsacemo*per0102 
/solution ; weight extri; where F3b=1 and t_firm=0; 
quit;


proc surveyreg data=m; title "Table GA3 DDD us_hours2 t_firm"; cluster  livdep ;class dyear CSE livdep ;
model us_hours2=dyear livdep CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl 
t_firm*dyear t_firm*CSE t_firm*livdep 
alsacemo*per0102 
t_firm*alsacemo*per0102 
/solution ; weight extri; where F3b=1 ; 
quit;


proc surveyreg data=m; title "Table GA3 DD us_hours2 t_sector=1"; cluster  livdep ;class dyear CSE livdep ;
model us_hours2=dyear livdep CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl 
alsacemo*per0102 
/solution ; weight extri; where F3b=1 and t_sector=1; 
quit;


proc surveyreg data=m; title "Table GA3 DD us_hours2 t_sector=0"; cluster  livdep ;class dyear CSE livdep ;
model us_hours2=dyear livdep CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl 
alsacemo*per0102 
/solution ; weight extri; where F3b=1 and t_sector=0; 
quit;


proc surveyreg data=m; title "Table GA3 DDD us_hours2 t_sector"; cluster  livdep ;class dyear CSE livdep ;
model us_hours2=dyear livdep CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl 
t_sector*dyear t_sector*CSE t_sector*livdep 
alsacemo*per0102 
t_sector*alsacemo*per0102 
/solution ; weight extri; where F3b=1 ; 
quit;

***********************************************************;
*CHECKS; 
***********************************************************;
*dISTRIBUTION OF dAYS OFF; 
proc freq data=m; 
title "Descriptive statistics for workers benefiting form Reduction working time";
tables H3REDN*alsacemo /NOROW NOPERCENT CELLCHI2 CHISQ;
where F3b=1 and HACCOR="1" ;
format alsacemo alsacemo.;
run;

***********************************************************;
*LOGISTIC REGRESSION INSTEAD OF LPM; 
***********************************************************;
proc surveylogistic data=m; title "D HREDUC1 "; cluster  livdep ;class year CSE ;model HREDUC1=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /link=logit ; weight extri; where F3b=1 ; quit;
proc surveylogistic data=m; title "D HACCOR1"; cluster  livdep ;class year CSE ;model HACCOR1=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /link=logit ; weight extri; where F3b=1 ; quit;
proc surveylogistic data=m; title "D rtt1"; cluster  livdep ;class year CSE ;model rtt1=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /link=logit ; weight extri; where F3b=1 and haccor='1'; quit;
proc surveylogistic data=m; title "D rtt2"; cluster  livdep ;class year CSE ;model rtt2=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /link=logit ; weight extri; where F3b=1 and haccor='1'; quit;
proc surveylogistic data=m; title "D rtt3"; cluster  livdep ;class year CSE ;model rtt3=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /link=logit ; weight extri; where F3b=1 and haccor='1'; quit;
proc surveylogistic data=m; title "D h3REDN13"; cluster  livdep ;class year CSE ;model h3REDN13=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /link=logit ; weight extri; where F3b=1 and haccor='1'; quit;
proc surveylogistic data=m; title "D h3REDN20"; cluster  livdep ;class year CSE ;model h3REDN20=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /link=logit ; weight extri; where F3b=1 and haccor='1'; quit;
proc surveylogistic data=m; title "D h3REDN21"; cluster  livdep ;class year CSE ;model h3REDN21=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /link=logit ; weight extri; where F3b=1 and haccor='1'; quit;
proc surveylogistic data=m; title "D rtt4"; cluster  livdep ;class year CSE ;model rtt4=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /link=logit ; weight extri; where F3b=1 and haccor='1'; quit;
proc surveylogistic data=m; title "D rtt5"; cluster  livdep ;class year CSE ;model rtt5=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /link=logit ; weight extri; where F3b=1 and haccor='1'; quit;
proc surveylogistic data=m; title "D rtt6"; cluster  livdep ;class year CSE ;model rtt6=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /link=logit ; weight extri; where F3b=1 and haccor='1'; quit;
proc surveylogistic data=m; title "D rtt7"; cluster  livdep ;class year CSE ;model rtt7=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /link=logit ; weight extri; where F3b=1 and haccor='1'; quit;
proc surveylogistic data=m; title "D rtt8"; cluster  livdep ;class year CSE ;model rtt8=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /link=logit ; weight extri; where F3b=1 and haccor='1'; quit;
proc surveylogistic data=m; title "D hreffe1"; cluster  livdep ;class year CSE ;model hreffe1=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /link=logit ; weight extri; where F3b=1 and haccor='1'; quit;
proc surveylogistic data=m; title "D hcrtt3"; cluster  livdep ;class year CSE ;model hcrtt3=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /link=logit ; weight extri; where F3b=1 and haccor='1'; quit;
proc surveylogistic data=m; title "D freertt1"; cluster  livdep ;class year CSE ;model freertt1=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /link=logit ; weight extri; where F3b=1 and haccor='1'; quit;
proc surveylogistic data=m; title "D freertt2"; cluster  livdep ;class year CSE ;model freertt2=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /link=logit ; weight extri; where F3b=1 and haccor='1'; quit;
proc surveylogistic data=m; title "D freertt3"; cluster  livdep ;class year CSE ;model freertt3=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /link=logit ; weight extri; where F3b=1 and haccor='1'; quit;
proc surveylogistic data=m; title "D freertt4"; cluster  livdep ;class year CSE ;model freertt4=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /link=logit ; weight extri; where F3b=1 and haccor='1'; quit;
proc surveylogistic data=m; title "D freertt5"; cluster  livdep ;class year CSE ;model freertt5=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /link=logit ; weight extri; where F3b=1 and haccor='1'; quit;
proc surveylogistic data=m; title "D freertt6"; cluster  livdep ;class year CSE ;model freertt6=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /link=logit ; weight extri; where F3b=1 and haccor='1'; quit;
proc surveylogistic data=m; title "D freertt7"; cluster  livdep ;class year CSE ;model freertt7=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /link=logit ; weight extri; where F3b=1 and haccor='1'; quit;
proc surveylogistic data=m; title "D freertt9"; cluster  livdep ;class year CSE ;model freertt9=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /link=logit ; weight extri; where F3b=1 and haccor='1'; quit;
proc surveylogistic data=m; title "D gtravp123"; cluster  livdep ;class year CSE ;model gtravp123=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo /link=logit ; weight extri; where F3b=1 and haccor='1'; quit;

***********************************************************;
*OTHER CHECKS; 
***********************************************************;

proc surveyreg data=m; title "D us_hours2 (Field: HACCOR1) and RTT1=1 no other forms of RTT"; cluster  livdep ;class year CSE ;
model us_hours2=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl alsacemo rtt3/solution ; 
weight extri; where F3b=1 and haccor='1' and rtt1=1 and rtt2+rtt3+rtt4+rtt5+rtt6+rtt7+rtt8=0; quit;

proc surveyreg data=m; title "DD us_hours2 haccor1"; cluster  livdep ;class dyear CSE livdep ;
model us_hours2=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl 
haccor1
haccor1*CSE 
alsacemo 
haccor1*alsacemo
/solution ; weight extri; where F3b=1 ; 
quit;

proc surveyreg data=m; title "DD us_hours2 haccor1 & t_occ=1"; cluster  livdep ;class dyear CSE livdep ;
model us_hours2=CSE male hhldsize ddipl1--ddipl6 ddipl9 age1524 age4049 age5059 age60pl 
haccor1
haccor1*CSE 
alsacemo 
haccor1*alsacemo
/solution ; weight extri; where F3b=1 and t_occ=1; 
quit;
