*************************************
* RAW DATA created with SAS software
* cf. Append_table_G6.sas
************************************
clear
set more off
set matsize 1000
import sasxport "D:\Olivier\Documents\Universite\Data\Emploi\dur9501_raw.xpt"
*import sasxport "C:\Users\olivier.godechot\Documents\Universite\Data\Emploi\dur9501_raw.xpt"

describe

*Conversion of factor to numeric variable
destring hh, gen (hh_n) force
*destring efen98, gen (efen98_n) force
destring ag, gen (ag_n) force
*destring age, gen (age_n) force
destring ht, gen (ht_n) force
destring cse, gen (cse_n) force

*destring hhc, gen (hhc_n) force
*destring empnbh, gen (empnbh_n) force
*destring efen, gen (efen_n) force
*destring nbinde, gen (nbinde_n) force
*acteu

destring dea, gen (year2)
*replace year2=2003 if annee=="2003"
gen year3=(year2<=100)*(year2+1900)+(year2>100)*(year2)


*Usual working hours
gen us_hours=hh_n
*replace us_hours=hhc if year==2003

 
*Last week working hours
gen lw_hours=ht_n
*replace lw_hours=empnbh if year==2003

*Hourly wage
replace salred=salred*6.55957 if year==2003
gen hwage=salred/(4.34*min(us_hours,48)) if us_hours>0 & missing(us_hours)==0
gen lhwage=log(hwage) if hwage>0 & missing(hwage)==0

*Full time 
gen fulltim=(inlist(duhab,"4","5","6","7"))

*gender
*gen female=(sexe=="2"  | s=="2")
gen female=(s=="2")
gen male=1-female

*civil servant
gen public=(chpub == "2")
*replace public=inlist(chpub,"1","2","3") if year==2003

*wage earner
gen wageearn=(st == "2")
*replace wageearn=(stat2 == "2") if year==2003


*definition of living department (department fixed effect)
gen livdep=dep
replace livdep="20" if inlist(livdep,"2A","2B")
destring livdep, replace

*definition of working department (department fixed effect)
gen workdep=depeta if year<2003
*replace workdep=deparc if year==2003
replace workdep="20" if inlist(workdep,"2A","2B")
destring workdep, replace
replace workdep=livdep if missing(workdep) 

* Border workers
gen borderwo=(1-(peta=="10" | peta==""))

****establish the correspondance with the border country:
gen country="Belgium" if livdep==59|livdep==08|livdep==55
replace country="Luxembourg" if livdep==54
replace country="Germany" if livdep==57|livdep==67|livdep==68
replace country="Switzerland" if livdep==90|livdep==25|livdep==39|livdep==1|livdep==74
replace country="Italy" if livdep==73|livdep==74|livdep==4|livdep==5|livdep==6
replace country="Spain" if livdep==66|livdep==9|livdep==31|livdep==65|livdep==64
replace country="No border" if missing(country)==1


gen country1=1-(country=="No border")
*Adding AISNE (very short border with Belgium)
replace country1=1 if livdep==2

gen country2=(inlist (country,"Belgium","Luxembourg","Germany","Switzerland"))



* Border Department * Growth
gen bordergdp=0 if country=="No border"
replace bordergdp=1.58960805579247 if country=="Belgium" & year==1996
replace bordergdp=3.7098969741779 if country=="Belgium" & year==1997
replace bordergdp=1.97648077819975 if country=="Belgium" & year==1998
replace bordergdp=3.56273663647085 if country=="Belgium" & year==1999
replace bordergdp=3.64016036893688 if country=="Belgium" & year==2000
replace bordergdp=0.805943529168277 if country=="Belgium" & year==2001
replace bordergdp=1.77955176068139 if country=="Belgium" & year==2002
replace bordergdp=0.774248667313357 if country=="Belgium" & year==2003
replace bordergdp=0.853803107702814 if country=="Germany" & year==1996
replace bordergdp=1.90478756470841 if country=="Germany" & year==1997
replace bordergdp=1.7755820082395 if country=="Germany" & year==1998
replace bordergdp=1.84519905837833 if country=="Germany" & year==1999
replace bordergdp=3.19740195821453 if country=="Germany" & year==2000
replace bordergdp=1.83767366339264 if country=="Germany" & year==2001
replace bordergdp=0.018796971665527 if country=="Germany" & year==2002
replace bordergdp=-0.730261487285155 if country=="Germany" & year==2003
replace bordergdp=1.52021815057823 if country=="Luxembourg" & year==1996
replace bordergdp=5.95023422423793 if country=="Luxembourg" & year==1997
replace bordergdp=6.48430414707796 if country=="Luxembourg" & year==1998
replace bordergdp=8.42348341729952 if country=="Luxembourg" & year==1999
replace bordergdp=8.4138511615165 if country=="Luxembourg" & year==2000
replace bordergdp=2.14738895086324 if country=="Luxembourg" & year==2001
replace bordergdp=3.62592944338009 if country=="Luxembourg" & year==2002
replace bordergdp=1.41294747363995 if country=="Luxembourg" & year==2003
replace bordergdp=2.67477982295753 if country=="Spain" & year==1996
replace bordergdp=3.68947185154924 if country=="Spain" & year==1997
replace bordergdp=4.30597844697085 if country=="Spain" & year==1998
replace bordergdp=4.48477443037206 if country=="Spain" & year==1999
replace bordergdp=5.28922090746535 if country=="Spain" & year==2000
replace bordergdp=4.00106922543372 if country=="Spain" & year==2001
replace bordergdp=2.87976212105771 if country=="Spain" & year==2002
replace bordergdp=3.18757147564503 if country=="Spain" & year==2003
replace bordergdp=0.553143472905909 if country=="Switzerland" & year==1996
replace bordergdp=2.28249395074228 if country=="Switzerland" & year==1997
replace bordergdp=2.86759553716691 if country=="Switzerland" & year==1998
replace bordergdp=1.59413007109722 if country=="Switzerland" & year==1999
replace bordergdp=4.1730931201534 if country=="Switzerland" & year==2000
replace bordergdp=1.45704410800672 if country=="Switzerland" & year==2001
replace bordergdp=0.147402714479676 if country=="Switzerland" & year==2002
replace bordergdp=0.080114046598927 if country=="Switzerland" & year==2003
replace bordergdp=1.00012290887587 if country=="Italy" & year==1996
replace bordergdp=1.96767328011084 if country=="Italy" & year==1997
replace bordergdp=1.45619718946013 if country=="Italy" & year==1998
replace bordergdp=1.5085997667673 if country=="Italy" & year==1999
replace bordergdp=3.96835161235477 if country=="Italy" & year==2000
replace bordergdp=1.58146107576628 if country=="Italy" & year==2001
replace bordergdp=0.24728101400427 if country=="Italy" & year==2002
replace bordergdp=0.238103105481728 if country=="Italy" & year==2003



*Redefinition of living region => Moselle in Alsace
gen livreg=rg if year<2003
*replace livreg=reg if missing(livreg) & year==2003
replace livreg="42" if livdep==57
destring livreg, replace

*Alsace Moselle 
* Living in Alsace-Moselle
gen alsacemo=(inlist (livdep,57,67,68))

* Working or Living in Alsace-Moselle
gen alsacemo_o=(inlist (workdep,57,67,68))

*Size of firm
*gen efen_n=efen
*replace efen_n=. if efen==999999
*gen efen99=(missing(efen_n)==1 | efen_n==999999)
*gen efen20=(efen_n>19 & efen_n<999999 & missing(efen_n)==0)
*gen efen20w=efen20  if efen99==0
*gen efen20e=(efen_n>19)

gen tn20=(inlist(tn,"5","6","7","8","9"))
gen tn99=(tn == "")
gen tn0=(tn=="0")
gen tn99b=(tn == "" | tn=="0")
gen tn20w=tn20 if tn99==0
gen tn20wb=tn20 if tn99==0 & tn0==0
gen tn20e=tn20+tn99b



*gen nbsalb20=(inlist(nbsalb,"5","6","7","8","9"))
*gen nbsalb99=(inlist(nbsalb,"","99"))
*gen nbsalb20w=nbsalb20 if nbsalb99==0

*targeted occupation
gen t_occ=(cse_n>31 & cse_n<70 &  cse !="34" & cse !="44" & cse !="42" & cse !="56")

*targeted firm 
gen t_firm=1 if public==1
*replace t_firm=1 if t_firm==. & year==2003 & efen20==1 & efen99==0
*replace t_firm=0 if t_firm==. & year==2003 & efen20==0 & efen99==0
*replace t_firm=1 if t_firm==. & year==2003 & efen99==1 & (inlist(nbsalb,"5","6","7","8","9")) 
*replace t_firm=0 if t_firm==. & year==2003 & efen99==1 & (inlist(nbsalb,"0","1","2","3","4")) 
replace t_firm=1 if t_firm==. & year<2003 & (inlist(tn,"5","6","7","8","9"))
replace t_firm=0 if t_firm==. & year<2003 & year>1997 & (inlist(tn,"0","1","2","3","4"))
replace t_firm=0 if t_firm==. & year<1998 & (inlist(tn,"1","2","3","4"))
replace t_firm=0 if t_firm==. & wageearn==0

*targeted firm with inclusions of missing in small firms
gen t_firmb=t_firm
replace t_firmb=0 if t_firm==.
gen t_firm99=(t_firm==.)
gen t_firm0=(t_firm==0)

*targeted sector
gen sector=nafg36
*replace sector=nafg36u if  year==2003
gen t_sector=(inlist(sector,"F5","J3","P1","H0"))

*targeted individuals
gen t_ind=((t_occ+t_firm+t_sector)>=3)
replace t_ind=. if t_firm==.

*age with numeric variable
gen agen=ag_n if year<2003
*replace agen=age_n if year==2003
gen age1524=(15<=agen & agen<=24)
gen age2539=(25<=agen & agen<=39)
gen age4049=(40<=agen & agen<=49)
gen age5059=(50<=agen & agen<=59)
gen age60pl=(60<=agen & agen<108)

*age with AG5
*tab ag5, gen(ag5dum)
gen ag5dum1=age1524
gen ag5dum2=age2539
gen ag5dum4=age4049
gen ag5dum5=age5059
gen ag5dum6=age60pl

*household size 
gen hhldsize=np if year<2003
*replace hhldsize=nbinde if year==2003
replace hhldsize=5 if hhldsize>=5

*diploma 
gen ddipl1=(ddipl == "1")
gen ddipl3=(ddipl == "3")
gen ddipl4=(ddipl == "4")
gen ddipl5=(ddipl == "5")
gen ddipl6=(ddipl == "6")
gen ddipl7=(ddipl == "7")
gen ddipl9=(ddipl == "")

*skilled
gen skilled=(ddipl=="1" | ddipl=="3")
gen skilled_o=(ddipl=="1" | ddipl=="3" | ddipl=="4")

*period
gen per9900=(year == 1999 | year == 2000)
gen per0102=(year == 2001 | year == 2002)
gen per03=(year == 2003)

*employment
gen act3=act
*replace act3=acteu if year==2003
gen employed=(act3 == "1")
gen unemploy=(act3 == "2") if inlist(act3,"1","2")

gen act7_n=act7
*replace act7_n=acteu6 if year==2003
destring act7_n, replace





 
gen all=1

*Interaction variables
*alsacemo*periods
gen alsacemo9900=alsacemo*per9900
gen alsacemo0102=alsacemo*per0102
gen alsacemo03=alsacemo*per03
gen alsacemo01=alsacemo*(year==2001)



*fields
*field all workers
gen f1=((act7_n==1|act7_n==3|act7_n==4))

*field all workers full time
gen f2=(f1 == 1 & fulltim == 1)

*field all workers full time and department, household and valid
gen f3=(f2==1 & missing(cse_n)==0 &  missing(us_hours)==0 ///
 & missing(hhldsize)==0 & missing(livdep)==0 & missing(ag5)==0 & extri !=. & extri !=0)

*field all workers full time and department, household and valid & not working abroad
gen f3b=(f3==1 & borderwo==0)


*Dur1995 and Dur2001 variables

gen us_hours2=durhebdo/60 if year==1995 
replace us_hours2=dthpr if year==2001

gen hreduc1=(hreduc=="1") if dyear==2001
gen haccor1=(haccor=="1") if dyear==2001
gen gtravp123=(inlist(gtravp,"1","2","3")) if dyear==2001

gen  rtt1=(hredui1=="1" |hredui2=="1" | hredui3=="1" | hredui4=="1") if haccor=="1" & dyear==2001
gen  rtt2=(hredui1=="2" |hredui2=="2" | hredui3=="2" | hredui4=="2") if haccor=="1" & dyear==2001
gen  rtt3=(hredui1=="3" |hredui2=="3" | hredui3=="3" | hredui4=="3") if haccor=="1" & dyear==2001
gen  rtt4=(hredui1=="4" |hredui2=="4" | hredui3=="4" | hredui4=="4") if haccor=="1" & dyear==2001
gen  rtt5=(hredui1=="5" |hredui2=="5" | hredui3=="5" | hredui4=="5") if haccor=="1" & dyear==2001
gen  rtt6=(hredui1=="6" |hredui2=="6" | hredui3=="6" | hredui4=="6") if haccor=="1" & dyear==2001
gen  rtt7=(hredui1=="7" |hredui2=="7" | hredui3=="7" | hredui4=="7") if haccor=="1" & dyear==2001
gen  rtt8=(hredui1=="8" |hredui2=="8" | hredui3=="8" | hredui4=="8") if haccor=="1" & dyear==2001
gen  rtt9=(hredui1=="" & hredui2=="" & hredui3=="" & hredui4=="") if haccor=="1" & dyear==2001

gen  freertt1=(hlrtt1=="1" |hlrtt2=="1" | hlrtt3=="1" | hlrtt4=="1") if haccor=="1" & dyear==2001
gen  freertt2=(hlrtt1=="2" |hlrtt2=="2" | hlrtt3=="2" | hlrtt4=="2") if haccor=="1" & dyear==2001
gen  freertt3=(hlrtt1=="3" |hlrtt2=="3" | hlrtt3=="3" | hlrtt4=="3") if haccor=="1" & dyear==2001
gen  freertt4=(hlrtt1=="4" |hlrtt2=="4" | hlrtt3=="4" | hlrtt4=="4") if haccor=="1" & dyear==2001
gen  freertt5=(hlrtt1=="5" |hlrtt2=="5" | hlrtt3=="5" | hlrtt4=="5") if haccor=="1" & dyear==2001
gen  freertt6=(hlrtt1=="6" |hlrtt2=="6" | hlrtt3=="6" | hlrtt4=="6") if haccor=="1" & dyear==2001
gen  freertt7=(hlrtt1=="7" |hlrtt2=="7" | hlrtt3=="7" | hlrtt4=="7") if haccor=="1" & dyear==2001
gen  freertt9=(hlrtt1=="" & hlrtt2=="" & hlrtt3=="" & hlrtt4=="") if haccor=="1" & dyear==2001


gen h3redn=h3red
replace h3redn=. if h3redn==99 

gen  h3rednb=h3redn
replace h3rednb=23 if h3rednb>22 

gen  h3redn13=(h3redn>0 & h3redn<14) if h3red != .
gen  h3redn20=(h3redn>13 & h3redn<21) if h3red != .
gen  h3redn21=(h3redn>20) if h3red != . 

gen  hreffe1=(hreffe=="1") if hreffe != ""  

gen  hcrtt1=(hcrtt=="1") if hcrtt != "" 
gen  hcrtt2=(hcrtt=="2") if hcrtt != "" 
gen  hcrtt3=(hcrtt=="3") if hcrtt != ""





**************************************************************************************
* Table G6. Descriptive statistics
**************************************************************************************
tabstat us_hours us_hours2 if f3b==1 & dyear==1995, by(alsacemo) st(me sd co) col(stat)
tabstat us_hours us_hours2 hreduc1 haccor1 if f3b==1 & dyear==2001, by(alsacemo) st(me sd co) col(stat)
tabstat us_hours us_hours2 rtt1-rtt3 h3redn h3redn13 h3redn20 h3redn21 rtt4-rtt8 ///
hreffe1 hcrtt3 freertt1-freertt9 gtravp123 ///
if f3b==1 & haccor=="1", by(alsacemo) st(me sd co) col(stat)



**************************************************************************************
* Table G6. Regressions
**************************************************************************************
regress us_hours alsacemo i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* if f3b==1 & year==1995 [pweight=extri], cluster(livdep)
outreg2 using "table_G6.xls", bdec(4) se ctitle("us_hours 1995") bracket replace
regress us_hours alsacemo i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* if f3b==1 & year==2001 [pweight=extri], cluster(livdep)
outreg2 using "table_G6.xls", bdec(4) se ctitle("us_hours 2001") bracket append
regress us_hours2 alsacemo i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* if f3b==1 & year==1995 [pweight=extri], cluster(livdep)
outreg2 using "table_G6.xls", bdec(4) se ctitle("us_hours2 1995") bracket append
regress us_hours2 alsacemo i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* if f3b==1 & year==2001 [pweight=extri], cluster(livdep)
outreg2 using "table_G6.xls", bdec(4) se ctitle("us_hours2 2001") bracket append

regress hreduc1 alsacemo i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* if f3b==1 [pweight=extri], cluster(livdep)
outreg2 using "table_G6.xls", bdec(4) se ctitle("hreduc1") bracket append
regress haccor1 alsacemo i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* if f3b==1 [pweight=extri], cluster(livdep)
outreg2 using "table_G6.xls", bdec(4) se ctitle("haccor1") bracket append

regress us_hours alsacemo i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* if f3b==1 & haccor1==1 [pweight=extri], cluster(livdep)
outreg2 using "table_G6.xls", bdec(4) se ctitle("us_hours haccor1") bracket append
regress us_hours2 alsacemo i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* if f3b==1 & haccor1==1 [pweight=extri], cluster(livdep)
outreg2 using "table_G6.xls", bdec(4) se ctitle("us_hours2 haccor1") bracket append
regress rtt1 alsacemo i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* if f3b==1 & haccor1==1 [pweight=extri], cluster(livdep)
outreg2 using "table_G6.xls", bdec(4) se ctitle("rtt1") bracket append
regress rtt2 alsacemo i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* if f3b==1 & haccor1==1 [pweight=extri], cluster(livdep)
outreg2 using "table_G6.xls", bdec(4) se ctitle("rtt2") bracket append
regress rtt3 alsacemo i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* if f3b==1 & haccor1==1 [pweight=extri], cluster(livdep)
outreg2 using "table_G6.xls", bdec(4) se ctitle("rtt3") bracket append
regress h3redn alsacemo i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* if f3b==1 & haccor1==1 [pweight=extri], cluster(livdep)
outreg2 using "table_G6.xls", bdec(4) se ctitle("h3redn") bracket append
regress h3redn13 alsacemo i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* if f3b==1 & haccor1==1 [pweight=extri], cluster(livdep)
outreg2 using "table_G6.xls", bdec(4) se ctitle("h3redn13") bracket append
regress h3redn20 alsacemo i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* if f3b==1 & haccor1==1 [pweight=extri], cluster(livdep)
outreg2 using "table_G6.xls", bdec(4) se ctitle("h3redn20") bracket append
regress h3redn21 alsacemo i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* if f3b==1 & haccor1==1 [pweight=extri], cluster(livdep)
outreg2 using "table_G6.xls", bdec(4) se ctitle("h3redn21") bracket append
regress rtt4 alsacemo i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* if f3b==1 & haccor1==1 [pweight=extri], cluster(livdep)
outreg2 using "table_G6.xls", bdec(4) se ctitle("rtt4") bracket append
regress rtt5 alsacemo i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* if f3b==1 & haccor1==1 [pweight=extri], cluster(livdep)
outreg2 using "table_G6.xls", bdec(4) se ctitle("rtt5") bracket append
regress rtt6 alsacemo i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* if f3b==1 & haccor1==1 [pweight=extri], cluster(livdep)
outreg2 using "table_G6.xls", bdec(4) se ctitle("rtt6") bracket append
regress rtt7 alsacemo i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* if f3b==1 & haccor1==1 [pweight=extri], cluster(livdep)
outreg2 using "table_G6.xls", bdec(4) se ctitle("rtt7") bracket append
regress rtt8 alsacemo i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* if f3b==1 & haccor1==1 [pweight=extri], cluster(livdep)
outreg2 using "table_G6.xls", bdec(4) se ctitle("rtt8") bracket append
regress hreffe1 alsacemo i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* if f3b==1 & haccor1==1 [pweight=extri], cluster(livdep)
outreg2 using "table_G6.xls", bdec(4) se ctitle("hreffe1") bracket append
regress hcrtt3 alsacemo i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* if f3b==1 & haccor1==1 [pweight=extri], cluster(livdep)
outreg2 using "table_G6.xls", bdec(4) se ctitle("hcrtt3") bracket append
regress freertt1 alsacemo i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* if f3b==1 & haccor1==1 [pweight=extri], cluster(livdep)
outreg2 using "table_G6.xls", bdec(4) se ctitle("freertt1") bracket append
regress freertt2 alsacemo i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* if f3b==1 & haccor1==1 [pweight=extri], cluster(livdep)
outreg2 using "table_G6.xls", bdec(4) se ctitle("freertt2") bracket append
regress freertt3 alsacemo i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* if f3b==1 & haccor1==1 [pweight=extri], cluster(livdep)
outreg2 using "table_G6.xls", bdec(4) se ctitle("freertt3") bracket append
regress freertt4 alsacemo i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* if f3b==1 & haccor1==1 [pweight=extri], cluster(livdep)
outreg2 using "table_G6.xls", bdec(4) se ctitle("freertt4") bracket append
regress freertt5 alsacemo i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* if f3b==1 & haccor1==1 [pweight=extri], cluster(livdep)
outreg2 using "table_G6.xls", bdec(4) se ctitle("freertt5") bracket append
regress freertt6 alsacemo i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* if f3b==1 & haccor1==1 [pweight=extri], cluster(livdep)
outreg2 using "table_G6.xls", bdec(4) se ctitle("freertt6") bracket append
regress freertt7 alsacemo i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* if f3b==1 & haccor1==1 [pweight=extri], cluster(livdep)
outreg2 using "table_G6.xls", bdec(4) se ctitle("freertt7") bracket append
regress freertt9 alsacemo i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* if f3b==1 & haccor1==1 [pweight=extri], cluster(livdep)
outreg2 using "table_G6.xls", bdec(4) se ctitle("freertt9") bracket append
regress gtravp123 alsacemo i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* if f3b==1 & haccor1==1 [pweight=extri], cluster(livdep)
outreg2 using "table_G6.xls", bdec(4) se ctitle("gtravp123") bracket append


**************************************************************************************
* Table GA3. Replication of TABLE A1
**************************************************************************************
regress us_hours2 i.year i.livdep i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* ///
alsacemo01 if f3b==1 & t_occ==1 [pweight=extri], cluster(livdep)
outreg2 using "table_1_GA3.xls", bdec(4) se ctitle("DD Target occ") bracket replace
outreg2 using "table_1_GA3_s.xls", bdec(4) se ctitle("DD Target occ") keep(alsacemo*) bracket replace

regress us_hours2 i.year i.livdep i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* ///
alsacemo01 if f3b==1 & t_occ==0 [pweight=extri], cluster(livdep)
outreg2 using "table_1_GA3.xls", bdec(4) se ctitle("DD Control occ") bracket append
outreg2 using "table_1_GA3_s.xls", bdec(4) se ctitle("DD Control occ") keep(alsacemo*) bracket append

regress us_hours2 t_occ##i.year t_occ##i.livdep t_occ##i.cse_n ddipl1 ///
ddipl3 ddipl4 ddipl5 ddipl6 ddipl9 ///
male hhldsize ag5dum*  ///
alsacemo01 ///
t_occ##alsacemo01 if f3b==1 [pweight=extri], cluster(livdep)
outreg2 using "table_1_GA3.xls", bdec(4) se ctitle("DDD occ") bracket append
outreg2 using "table_1_GA3_s.xls", bdec(4) se ctitle("DDD occ") keep(alsacemo* t_occ##alsacemo*) bracket append


regress us_hours2 i.year i.livdep i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum*  ///
alsacemo01 if f3b==1 & t_ind==1 [pweight=extri], cluster(livdep)
outreg2 using "table_1_GA3.xls", bdec(4) se ctitle("DD Target ind") bracket append
outreg2 using "table_1_GA3_s.xls", bdec(4) se ctitle("DD Target ind") keep(alsacemo*) bracket append



regress us_hours2 i.year i.livdep i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* ///
alsacemo01 if f3b==1 & t_ind==0 [pweight=extri], cluster(livdep)
outreg2 using "table_1_GA3.xls", bdec(4) se ctitle("DD Control ind") bracket append
outreg2 using "table_1_GA3_s.xls", bdec(4) se ctitle("DD Control ind") keep(alsacemo*) bracket append


regress us_hours2 t_ind##i.year t_ind##i.livdep t_ind##i.cse_n  ddipl1 ///
ddipl3 ddipl4 ddipl5 ddipl6 ddipl9 ///
male hhldsize ag5dum*  ///
alsacemo01 ///
t_ind##alsacemo01 if f3b==1 [pweight=extri], cluster(livdep)
outreg2 using "table_1_GA3.xls", bdec(4) se ctitle("DDD ind") bracket append
outreg2 using "table_1_GA3_s.xls", bdec(4) se ctitle("DDD ind") keep(alsacemo* t_ind##alsacemo*) bracket append




**************************************************************************************
* Table GA3. PANEL B. REPLICATION OF TABLE A2. Excluding borderworkers
**************************************************************************************


regress us_hours2 i.year i.livdep i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* ///
alsacemo01 if f3b==1 & t_firm==1 [pweight=extri], cluster(livdep)
outreg2 using "table_A2_GA3.xls", bdec(4) se ctitle("DD Target firm") bracket replace
outreg2 using "table_A2_GA3_s.xls", bdec(4) se ctitle("DD Target firm") keep(alsacemo*) bracket replace

regress us_hours2 i.year i.livdep i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* ///
alsacemo01 if f3b==1 & t_firm==0 [pweight=extri], cluster(livdep)
outreg2 using "table_A2_GA3.xls", bdec(4) se ctitle("DD Control firm") bracket append
outreg2 using "table_A2_GA3_s.xls", bdec(4) se ctitle("DD Control firm") keep(alsacemo*) bracket append

regress us_hours2 t_firm##i.year t_firm##i.livdep t_firm##i.cse_n  ddipl1 ///
ddipl3 ddipl4 ddipl5 ddipl6 ddipl9 ///
male hhldsize ag5dum*  ///
alsacemo01 ///
t_firm##alsacemo01 if f3b==1 [pweight=extri], cluster(livdep)
outreg2 using "table_A2_GA3.xls", bdec(4) se ctitle("DDD firm") bracket append
outreg2 using "table_A2_GA3_s.xls", bdec(4) se ctitle("DDD firm") keep(alsacemo* t_firm##alsacemo*) bracket append

regress us_hours2 i.year i.livdep i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* ///
alsacemo01 if f3b==1 & t_sector==1 [pweight=extri], cluster(livdep)
outreg2 using "table_A2_GA3.xls", bdec(4) se ctitle("DD Target sector") bracket append
outreg2 using "table_A2_GA3_s.xls", bdec(4) se ctitle("DD Target sector") keep(alsacemo*) bracket append


regress us_hours2 i.year i.livdep i.cse_n ddipl1-ddipl6 ddipl9 male hhldsize ag5dum* ///
alsacemo01 if f3b==1 & t_sector==0 [pweight=extri], cluster(livdep)
outreg2 using "table_A2_GA3.xls", bdec(4) se ctitle("DD Control sector") bracket append
outreg2 using "table_A2_GA3_s.xls", bdec(4) se ctitle("DD Control sector") keep(alsacemo*) bracket append

regress us_hours2 t_sector##i.year t_sector##i.livdep t_sector##i.cse_n  ddipl1 ///
ddipl3 ddipl4 ddipl5 ddipl6 ddipl9 ///
male hhldsize ag5dum*  ///
alsacemo01 ///
t_sector##alsacemo01 if f3b==1 [pweight=extri], cluster(livdep)
outreg2 using "table_A2_GA3.xls", bdec(4) se ctitle("DDD sector") bracket append
outreg2 using "table_A2_GA3_s.xls", bdec(4) se ctitle("DDD sector") keep(alsacemo* t_sector##alsacemo*) bracket append





